SystemOrganization addCategory: #ConfigurationOfGrease!

Object subclass: #ConfigurationOfGrease
	instanceVariableNames: 'project'
	classVariableNames: 'LastVersionLoad'
	poolDictionaries: ''
	category: 'ConfigurationOfGrease'!

!ConfigurationOfGrease commentStamp: 'StephaneDucasse 10/18/2011 14:07' prior: 0!
(ConfigurationOfGrease project version: #stable) load

(ConfigurationOfGrease project version: #development) load!

!ConfigurationOfGrease class methodsFor: 'development support' stamp: 'DaleHenrichs 12/06/2010 13:20'!
DevelopmentProcess

"DEVELOPMENT Process
	- load current version:
	  	(self project version: #stable) load: 'ALL'.
	- open new version for development:
		self createNewDevelopmentVersion
	- update the the development version to match mcz file versions
		self updateToLatestPackageVersions: '- fixed bug uvw'
	- do development and periodically save mcz files and update configuration
		self saveModifiedPackages: '- fixed bug xyz'
	- do development and periodically save mcz files and configuration until ready for release
		self saveModifiedPackagesAndConfiguration: '- fixed bug xyz'
	- save configuration
		self saveConfiguration: commitMessage '- checkpoint configuration'
RELEASE Process
	- mark development version as release:
		self releaseDevelopmentVersion: 'commit comment'
	- copy configuration for general access for Squeak and Pharo:
		self copyToSqueakSource.
	- copy configuration for general access for GLASS (Dale is willing to test and release for GLASS):
		self copyToGemSource.
"! !

!ConfigurationOfGrease class methodsFor: 'private' stamp: 'dkh 11/12/2009 09:11'!
bootstrapPackage: aString from: aPath 
	| repository version |
	repository := MCHttpRepository
				location: aPath
				user: ''
				password: ''.
	repository
		versionReaderForFileNamed: aString , '.mcz'
		do: [:reader | 
			version := reader version.
			version load.
			version workingCopy repositoryGroup addRepository: repository]! !

!ConfigurationOfGrease class methodsFor: 'development support' stamp: 'DaleHenrichs 1/14/2011 11:50'!
compareVersions
	"Compare the current #stable version to current #development version"

	"self compareVersions"

	"Note: you need 1.0-beta.28 or later for the class MetacelloToolBox"

	self ensureMetacello.
	((Smalltalk at: #MetacelloToolBox) compareVersionsIn: self) inspect
! !

!ConfigurationOfGrease class methodsFor: 'development support' stamp: 'DaleHenrichs 12/06/2010 13:19'!
copyToGemSource
	"Copy the current configuration mcz file to http://seaside.gemstone.com/ss/MetacelloRepository"

	"Note you before copying config to GemSource, you should have tested the release in GLASS.
	 You also need to have commit rights to the GemSource repository."

	"self copyToGemSource"

	"Note: you need 1.0-beta.28 or later for the class MetacelloToolBox"

	self ensureMetacello.
	(Smalltalk at: #MetacelloToolBox) copyConfiguration: self to: 'http://seaside.gemstone.com/ss/MetacelloRepository'! !

!ConfigurationOfGrease class methodsFor: 'development support' stamp: 'DaleHenrichs 12/06/2010 13:19'!
copyToSqueakSource
	"Copy the current configuration mcz file to http://www.squeaksource.com/MetacelloRepository"

	"self copyToSqueakSource"

	"Note: you need 1.0-beta.28 or later for the class MetacelloToolBox"

	self ensureMetacello.
	(Smalltalk at: #MetacelloToolBox) copyConfiguration: self to: 'http://www.squeaksource.com/MetacelloRepository'! !

!ConfigurationOfGrease class methodsFor: 'development support' stamp: 'DaleHenrichs 1/11/2011 15:02'!
createNewBaselineVersion
	"Create a new baseline version based upon #stable version's baseline.
	 A new baseline should be created if new packages have been added or package dependencies have changed."

	"self createNewDevelopmentVersion"
	
	"Note: you need 1.0-beta.28 or later for the class MetacelloToolBox"

	self ensureMetacello.
	(Smalltalk at: #MetacelloToolBox) createNewBaselineVersionIn: self description: ''
! !

!ConfigurationOfGrease class methodsFor: 'development support' stamp: 'DaleHenrichs 1/11/2011 15:01'!
createNewDevelopmentVersion
	"Create a new development version using the #stable version as model."

	"self createNewDevelopmentVersion"
	
	"Note: you need 1.0-beta.28 or later for the class MetacelloToolBox"

	self ensureMetacello.
	(Smalltalk at: #MetacelloToolBox) createNewDevelopmentVersionIn: self description: ''! !

!ConfigurationOfGrease class methodsFor: 'private' stamp: 'DaleHenrichs 06/22/2010 09:39'!
ensureMetacello
	"Bootstrap Gofer (if necessary), load latest mcz file for ConfigurationOfMetacello (using old 
	 Gofer API), then load the latest version of Metacello itself."

	Smalltalk at: #MetacelloProject ifAbsent: [ | error |
		"list of repositories to try, in case primary repository is not accessible"
		(Array 
			with: 'http://www.squeaksource.com/MetacelloRepository' 
			with: 'http://seaside.gemstone.com/ss/metacello') do: [:repositoryUrl |
				([
					Smalltalk at: #Gofer ifAbsent: [
						"Current version of Gofer from which to bootstrap - as of 1.0-beta.21"
						self bootstrapPackage: 'Gofer-Core-lr.115' from: repositoryUrl ].
					Smalltalk at: #Gofer ifPresent: [:goferClass | | gofer |
						gofer := goferClass new
							url: repositoryUrl;
							yourself.
						[ gofer addPackage: 'ConfigurationOfMetacello' ] on: Warning do: [:ex | ex resume ].
						gofer load ]]
							on: Error
							do: [ :ex |
								error := ex.
								Transcript 
									cr; 
									show: 'failed ensureMetacello: ';
									show: ex description printString;
									show: '...retrying'.
								"try again"
								ex return: nil ]) ~~ nil
					ifTrue: [
						"load 'default' group of Metacello"
						(Smalltalk at: #ConfigurationOfMetacello) perform: #load.
						^self ]].
		"shouldn't get here unless the load failed ... throw an error"
		self error: 'retry with alternate repository failed: ', error description printString ]! !

!ConfigurationOfGrease class methodsFor: 'metacello tool support' stamp: 'dkh 11/12/2009 09:11'!
isMetacelloConfig
	"Answer true and the Metacello tools will operate on you"
	
	^true! !

!ConfigurationOfGrease class methodsFor: 'metacello tool support' stamp: 'dkh 11/13/2009 16:33'!
lastMetacelloVersionLoad
	"Answer the last version loaded and the list of packages loaded for that version."

	LastVersionLoad == nil ifTrue: [ LastVersionLoad := nil -> 'default' ].
	^LastVersionLoad! !

!ConfigurationOfGrease class methodsFor: 'loading' stamp: 'dkh 11/12/2009 09:11'!
loadLatestVersion
	"self loadLatestVersion"
	
	^self project latestVersion load! !

!ConfigurationOfGrease class methodsFor: 'metacello tool support' stamp: 'dkh 11/13/2009 16:33'!
metacelloVersion: versionString loads: anArrayOrString
	"Stash the last version loaded and the list of packages loaded for that version. The list
	 of packages will be used by the tools when doing 'Load Package Version'"

	LastVersionLoad := versionString -> anArrayOrString! !

!ConfigurationOfGrease class methodsFor: 'accessing' stamp: 'dkh 11/12/2009 09:11'!
project

	^self new project! !

!ConfigurationOfGrease class methodsFor: 'development support' stamp: 'DaleHenrichs 1/11/2011 15:05'!
releaseDevelopmentVersion: commitMessage
	"Release #development version (set version blessing to #release), update the #development and #stable symbolic versions and save the configuration."

	"self releaseDevelopmentVersion: '- release version 1.0.2'"

	"Note: you need 1.0-beta.28 or later for the class MetacelloToolBox"

	self ensureMetacello.
	(Smalltalk at: #MetacelloToolBox) releaseDevelopmentVersionIn: self description: commitMessage! !

!ConfigurationOfGrease class methodsFor: 'development support' stamp: 'DaleHenrichs 12/06/2010 11:29'!
saveConfiguration: commitMessage
	"Save the configuration."

	"self saveConfiguration: '- fixed bug'"

	"Note: you need 1.0-beta.28 or later for the class MetacelloToolBox"

	self ensureMetacello.
	(Smalltalk at: #MetacelloToolBox) saveConfigurationPackageFor: self name asString description: commitMessage! !

!ConfigurationOfGrease class methodsFor: 'development support' stamp: 'DaleHenrichs 12/06/2010 11:31'!
saveModifiedPackages: commitMessage
	"Save modified mcz files and update the configuration."

	"self saveModifiedPackages: '- fixed bug'"

	"Note: you need 1.0-beta.28 or later for the class MetacelloToolBox"

	self ensureMetacello.
	(Smalltalk at: #MetacelloToolBox) saveModifiedPackagesIn: self description:  commitMessage! !

!ConfigurationOfGrease class methodsFor: 'development support' stamp: 'DaleHenrichs 12/06/2010 11:34'!
saveModifiedPackagesAndConfiguration: commitMessage
	"Save modified mcz files, update and then save the configuration."

	"self saveModifiedPackagesAndConfiguration: '- fixed bug'"

	"Note: you need 1.0-beta.28 or later for the class MetacelloToolBox"

	self ensureMetacello.
	(Smalltalk at: #MetacelloToolBox) saveModifiedPackagesAndConfigurationIn: self description: commitMessage! !

!ConfigurationOfGrease class methodsFor: 'development support' stamp: 'DaleHenrichs 2/11/2011 13:41'!
updateToLatestPackageVersions: descriptionString
	"Updates mcz file versions in current version"

	"self updateToLatestPackageVersions: '- latest mcz files for 1.0.4'"

	"Note: you need 1.0-beta.28 or later for the class MetacelloToolBox"

	self ensureMetacello.
	((Smalltalk at: #MetacelloToolBox) updateToLatestPackageVersionsIn: self description: descriptionString) isEmpty
		ifTrue: [ self inform: 'All specs up to date' ]! !

!ConfigurationOfGrease class methodsFor: 'development support' stamp: 'DaleHenrichs 12/06/2010 11:57'!
validate
	"Check the configuration for Errors, Critical Warnings, and Warnings (see class comment for MetacelloMCVersionValidator for more information). 
	Errors identify specification issues that will result in unexpected behaviour when you load the configuration. 
	Critical Warnings identify specification issues that may result in unexpected behavior when you load the configuration.
	Warnings identify specification issues that are technically correct, but are worth take a look at."
	
	"self validate"

	"Note: you need 1.0-beta.28 or later for the class MetacelloToolBox"

	self ensureMetacello.
	^ ((Smalltalk at: #MetacelloToolBox) validateConfiguration: self debug: #() recurse: false) explore! !

!ConfigurationOfGrease methodsFor: 'baselines' stamp: 'DaleHenrichs 11/17/2010 13:13'!
baseline1011: spec
	<version: '1.0.1.1-baseline'>

	spec for: #'common' do: [
		spec blessing: #'baseline'.
		spec description: ''.
		spec repository: 'http://www.squeaksource.com/Seaside30'.
		spec 
			package: 'Grease-Core';
			package: 'Grease-Tests-Core' with: [
				spec requires: #('Grease-Core' ). ].
		spec 
			group: 'Core' with: #('Grease-Core' );
			group: 'Core Tests' with: #('Grease-Tests-Core' );
			group: 'Slime' with: #('Core' );
			group: 'Slime Tests' with: #('Core Tests' );
			group: 'Tests' with: #('Core Tests' 'Slime Tests' );
			group: 'default' with: #('Slime' ).].

	spec for: #'squeakCommon' do: [
		spec 
			package: 'Grease-Core' with: [
				spec includes: #('Grease-Pharo-Core' ). ];
			package: 'Grease-Tests-Core' with: [
				spec includes: #('Grease-Tests-Pharo-Core' ). ];
			package: 'Grease-Pharo-Core' with: [
				spec requires: #('Grease-Core' ). ];
			package: 'Grease-Tests-Pharo-Core' with: [
				spec requires: #('Grease-Tests-Core' ). ].].

	spec for: #'pharo' do: [
		spec project: 'Refactoring-Core' with: [
				spec
					className: 'ConfigurationOfRefactoringBrowser';
					versionString: '1.4';
					loads: #('Refactoring-Core' );
					repository: 'http://www.squeaksource.com/MetacelloRepository' ].
		spec 
			package: 'Grease-Slime' with: [
				spec requires: #('Refactoring-Core' 'Grease-Core' ). ];
			package: 'Grease-Tests-Slime' with: [
				spec requires: #('Grease-Slime' ). ].
		spec 
			group: 'Slime' with: #('Grease-Slime' );
			group: 'Slime Tests' with: #('Grease-Tests-Slime' ).].

	spec for: #'GreaseForPharo1.0' do: [
		spec 
			package: 'Grease-Pharo-Core' with: [
				spec includes: #('Grease-Pharo10-Core' ). ];
			package: 'Grease-Pharo10-Core'.].

	spec for: #'gemstone' do: [
		spec repository: 'http://seaside.gemstone.com/ss/Seaside30'.
		spec 
			project: 'GsCore' with: [
				spec
					className: 'ConfigurationOfGsCore';
					versionString: '0.241';
					repository: 'http://seaside.gemstone.com/ss/MetacelloRepository' ];
			project: 'UTF8' with: [
				spec
					className: 'ConfigurationOfGsMisc';
					versionString: '0.237';
					loads: #('Utf8Encoding' );
					repository: 'http://seaside.gemstone.com/ss/MetacelloRepository' ];
			project: 'System-Digital-Signatures' copyFrom: 'UTF8' with: [
				spec loads: #('System-Digital-Signatures' ) ];
			project: 'SMTPMail' copyFrom: 'UTF8' with: [
				spec loads: #('SMTPMail' ) ].
		spec 
			package: 'Grease-Core' with: [
				spec includes: #('Grease-GemStone-Core' ). ];
			package: 'Grease-Tests-Core' with: [
				spec includes: #('Grease-Tests-GemStone-Core' ). ];
			package: 'Grease-GemStone-Core' with: [
				spec requires: #('Grease-Core' 'GsCore' 'System-Digital-Signatures' 'UTF8' 'SMTPMail' ). ];
			package: 'Grease-Tests-GemStone-Core' with: [
				spec requires: #('Grease-Tests-Core' ). ].].

	spec for: #'gs2.3.x' do: [
		spec 
			package: 'Grease-GemStone-Core' with: [
				spec includes: #('Grease-GemStone230-Core' ). ];
			package: 'Grease-GemStone230-Core' with: [
				spec requires: #('Grease-GemStone-Core' ). ].].

	spec for: #'gs2.4.x' do: [
		spec 
			package: 'Grease-GemStone-Core' with: [
				spec includes: #('Grease-GemStone240-Core' ). ];
			package: 'Grease-GemStone240-Core' with: [
				spec requires: #('Grease-GemStone-Core' ). ].].

	spec for: #'gs3.x' do: [
		spec 
			package: 'Grease-GemStone-Core' with: [
				spec includes: #('Grease-GemStone300-Core' ). ];
			package: 'Grease-GemStone300-Core' with: [
				spec requires: #('Grease-GemStone-Core' ). ].].
! !

!ConfigurationOfGrease methodsFor: 'baselines' stamp: 'DaleHenrichs 11/10/2010 10:22'!
baseline101: spec 
	<version: '1.0.1-baseline'>

	spec for: #common do: [
		spec blessing: #baseline.
		spec repository: 'http://www.squeaksource.com/Seaside30'.
		spec
			package: 'Grease-Core';
			package: 'Grease-Tests-Core' 
				with: [ spec requires: #('Grease-Core' ). ];
			yourself.
		spec
			group: 'Core' with: #('Grease-Core');
			group: 'Core Tests' with: #('Grease-Tests-Core');
			group: 'Slime' with: #('Core');
			group: 'Slime Tests' with: #('Core Tests');
			group: 'Tests' with: #('Core Tests' 'Slime Tests');
			group: 'default' with: #('Slime');
			yourself. ].

	spec for: #squeakCommon do: [
		spec
			package: 'Grease-Core' 
				with: [ spec includes: #('Grease-Pharo-Core' ) ];
			package: 'Grease-Tests-Core' 
				with: [ spec includes: #('Grease-Tests-Pharo-Core' ). ];
			package: 'Grease-Pharo-Core' 
				with: [ spec requires: #('Grease-Core' ) ];
			package: 'Grease-Tests-Pharo-Core' 
				with: [ spec requires: #('Grease-Tests-Core') ];					
			yourself. ].

	spec for: #pharo do: [
		spec
			project: 'Refactoring-Core' with: [
				spec
					className: 'ConfigurationOfRefactoringBrowser';
					versionString: '1.4';
					loads: #('Refactoring-Core' );
					repository: 'http://www.squeaksource.com/MetacelloRepository' ];
			yourself.
		spec
			package: 'Grease-Slime' 
				with: [ spec requires: #('Refactoring-Core' 'Grease-Core' ) ];
			package: 'Grease-Tests-Slime' 
				with: [ spec requires: #('Grease-Slime') ];					
			yourself.
		spec
			group: 'Slime' with: #('Grease-Slime');
			group: 'Slime Tests' with: #('Grease-Tests-Slime');
			yourself. ].
	spec for: #'GreaseForPharo1.0' do: [
		spec
			package: 'Grease-Pharo-Core'
				with: [ spec includes: #('Grease-Pharo10-Core' ) ];
			package: 'Grease-Pharo10-Core';
			yourself.].
	spec for: #gemstone do: [
		spec 
			repository: 'http://seaside.gemstone.com/ss/Seaside30'.

		spec 
			project: 'GsCore' with: [
				spec
					className: 'ConfigurationOfGsCore';
					versionString: '0.239.2-baseline';
					repository: 'http://seaside.gemstone.com/ss/MetacelloRepository' ];
			project: 'UTF8' with: [
				spec
					className: 'ConfigurationOfGsMisc';
					versionString: '0.237-baseline';
					loads: #('Utf8Encoding' );
					repository: 'http://seaside.gemstone.com/ss/MetacelloRepository' ];
			project: 'System-Digital-Signatures'
				copyFrom: 'UTF8'
				with: [ spec loads: #('System-Digital-Signatures' ) ];
			project: 'SMTPMail'
				copyFrom: 'UTF8'
				with: [ spec loads: #('SMTPMail' ) ];			
			yourself.

		spec
			package: 'Grease-Core' 
				with: [ spec includes: #('Grease-GemStone-Core' ) ];
			package: 'Grease-Tests-Core' 
				with: [ spec includes: #('Grease-Tests-GemStone-Core' ). ];
			package: 'Grease-GemStone-Core' 
				with: [ spec requires: #('Grease-Core' 'GsCore' 'System-Digital-Signatures' 'UTF8' 'SMTPMail' ) ];
			package: 'Grease-Tests-GemStone-Core' 
				with: [ spec requires: #('Grease-Tests-Core' ) ];
			yourself. ].

	spec for: #'gs2.3.x' do: [
		spec 
			package: 'Grease-GemStone-Core' 
				with: [ spec includes: #('Grease-GemStone230-Core' ) ];
			package: 'Grease-GemStone230-Core' 
				with: [ spec requires: #('Grease-GemStone-Core' ) ];
			yourself. ].
	spec for: #'gs2.4.x' do: [
		spec 
			package: 'Grease-GemStone-Core' 
				with: [ spec includes: #('Grease-GemStone240-Core' ) ];
			package: 'Grease-GemStone240-Core' 
				with: [ spec requires: #('Grease-GemStone-Core' ) ];
			yourself. ].
	spec for: #'gs3.x' do: [
		spec 
			package: 'Grease-GemStone-Core' 
				with: [ spec includes: #('Grease-GemStone300-Core' ) ];
			package: 'Grease-GemStone300-Core' 
				with: [ spec requires: #('Grease-GemStone-Core' ) ];
			yourself. ].
! !

!ConfigurationOfGrease methodsFor: 'baselines' stamp: 'pmm 11/21/2010 12:33'!
baseline102: spec
	<version: '1.0.2-baseline'>

	spec for: #'common' do: [
		spec blessing: #'baseline'.
		spec description: ''.
		spec repository: 'http://www.squeaksource.com/Seaside30'.
		spec 
			package: 'Grease-Core';
			package: 'Grease-Tests-Core' with: [
				spec requires: #('Grease-Core' ). ].
		spec 
			group: 'Core' with: #('Grease-Core' );
			group: 'Core Tests' with: #('Grease-Tests-Core' );
			group: 'Slime' with: #('Core' );
			group: 'Slime Tests' with: #('Core Tests' );
			group: 'Tests' with: #('Core Tests' 'Slime Tests' );
			group: 'default' with: #('Slime' ).].

	spec for: #'squeakCommon' do: [
		spec 
			package: 'Grease-Core' with: [
				spec includes: #('Grease-Pharo-Core' ). ];
			package: 'Grease-Tests-Core' with: [
				spec includes: #('Grease-Tests-Pharo-Core' ). ];
			package: 'Grease-Pharo-Core' with: [
				spec requires: #('Grease-Core' ). ];
			package: 'Grease-Tests-Pharo-Core' with: [
				spec requires: #('Grease-Tests-Core' ). ].].

	spec for: #'pharo' do: [
		spec project: 'Refactoring-Core' with: [
				spec
					className: 'ConfigurationOfRefactoringBrowser';
					versionString: '1.4';
					loads: #('Refactoring-Core' );
					repository: 'http://www.squeaksource.com/MetacelloRepository' ].
		spec 
			package: 'Grease-Slime' with: [
				spec requires: #('Refactoring-Core' 'Grease-Core' ). ];
			package: 'Grease-Tests-Slime' with: [
				spec requires: #('Grease-Slime' ). ].
		spec 
			group: 'Slime' with: #('Grease-Slime' );
			group: 'Slime Tests' with: #('Grease-Tests-Slime' ).].

	spec for: #'GreaseForPharo1.0' do: [
		spec 
			package: 'Grease-Pharo-Core' with: [
				spec includes: #('Grease-Pharo10-Core' ). ];
			package: 'Grease-Pharo10-Core'.].

	spec for: #'gemstone' do: [
		spec repository: 'http://seaside.gemstone.com/ss/Seaside30'.
		spec 
			project: 'GsCore' with: [
				spec
					className: 'ConfigurationOfGsCore';
					versionString: '0.241';
					repository: 'http://seaside.gemstone.com/ss/MetacelloRepository' ];
			project: 'UTF8' with: [
				spec
					className: 'ConfigurationOfGsMisc';
					versionString: '0.237';
					loads: #('Utf8Encoding' );
					repository: 'http://seaside.gemstone.com/ss/MetacelloRepository' ];
			project: 'System-Digital-Signatures' copyFrom: 'UTF8' with: [
				spec loads: #('System-Digital-Signatures' ) ];
			project: 'SMTPMail' copyFrom: 'UTF8' with: [
				spec loads: #('SMTPMail' ) ].
		spec 
			package: 'Grease-Core' with: [
				spec includes: #('Grease-GemStone-Core' ). ];
			package: 'Grease-Tests-Core' with: [
				spec includes: #('Grease-Tests-GemStone-Core' ). ];
			package: 'Grease-GemStone-Core' with: [
				spec requires: #('Grease-Core' 'GsCore' 'System-Digital-Signatures' 'UTF8' 'SMTPMail' ). ];
			package: 'Grease-Tests-GemStone-Core' with: [
				spec requires: #('Grease-Tests-Core' ). ].].

	spec for: #'gs2.3.x' do: [
		spec 
			package: 'Grease-GemStone-Core' with: [
				spec includes: #('Grease-GemStone230-Core' ). ];
			package: 'Grease-GemStone230-Core' with: [
				spec requires: #('Grease-GemStone-Core' ). ].].

	spec for: #'gs2.4.x' do: [
		spec 
			package: 'Grease-GemStone-Core' with: [
				spec includes: #('Grease-GemStone240-Core' ). ];
			package: 'Grease-GemStone240-Core' with: [
				spec requires: #('Grease-GemStone-Core' ). ].].

	spec for: #'gs3.x' do: [
		spec 
			package: 'Grease-GemStone-Core' with: [
				spec includes: #('Grease-GemStone300-Core' ). ];
			package: 'Grease-GemStone300-Core' with: [
				spec requires: #('Grease-GemStone-Core' ). ].].
! !

!ConfigurationOfGrease methodsFor: 'baselines' stamp: 'DaleHenrichs 02/01/2011 11:41'!
baseline103: spec
	<version: '1.0.3-baseline'>

	spec for: #'common' do: [
		spec blessing: #'baseline'.
		spec description: ''.
		spec repository: 'http://www.squeaksource.com/Seaside30'.
		spec 
			package: 'Grease-Core';
			package: 'Grease-Tests-Core' with: [
				spec requires: #('Grease-Core' ). ].
		spec 
			group: 'Core' with: #('Grease-Core' );
			group: 'Core Tests' with: #('Grease-Tests-Core' );
			group: 'Slime' with: #('Core' );
			group: 'Slime Tests' with: #('Core Tests' );
			group: 'Tests' with: #('Core Tests' 'Slime Tests' );
			group: 'default' with: #('Slime' ).].

	spec for: #'squeakCommon' do: [
		spec 
			package: 'Grease-Core' with: [
				spec includes: #('Grease-Pharo-Core' ). ];
			package: 'Grease-Tests-Core' with: [
				spec includes: #('Grease-Tests-Pharo-Core' ). ];
			package: 'Grease-Pharo-Core' with: [
				spec requires: #('Grease-Core' ). ];
			package: 'Grease-Tests-Pharo-Core' with: [
				spec requires: #('Grease-Tests-Core' ). ].].

	spec for: #'pharo' do: [
		spec project: 'Refactoring-Core' with: [
				spec
					className: 'ConfigurationOfRefactoringBrowser';
					versionString: '1.4';
					loads: #('Refactoring-Core' );
					repository: 'http://www.squeaksource.com/MetacelloRepository' ].
		spec 
			package: 'Grease-Slime' with: [
				spec requires: #('Refactoring-Core' 'Grease-Core' ). ];
			package: 'Grease-Tests-Slime' with: [
				spec requires: #('Grease-Slime' ). ].
		spec 
			group: 'Slime' with: #('Grease-Slime' );
			group: 'Slime Tests' with: #('Grease-Tests-Slime' ).].

	spec for: #'GreaseForPharo1.0' do: [
		spec 
			package: 'Grease-Pharo-Core' with: [
				spec includes: #('Grease-Pharo10-Core' ). ];
			package: 'Grease-Pharo10-Core'.].

	spec for: #'gemstone' do: [
		spec repository: 'http://seaside.gemstone.com/ss/Seaside30'.
		spec 
			project: 'GsCore' with: [
				spec
					className: 'ConfigurationOfGsCore';
					versionString: '0.241';
					repository: 'http://seaside.gemstone.com/ss/MetacelloRepository' ];
			project: 'UTF8' with: [
				spec
					className: 'ConfigurationOfGsMisc';
					versionString: '0.237';
					loads: #('Utf8Encoding' );
					repository: 'http://seaside.gemstone.com/ss/MetacelloRepository' ];
			project: 'System-Digital-Signatures' copyFrom: 'UTF8' with: [
				spec loads: #('System-Digital-Signatures' ) ];
			project: 'SMTPMail' copyFrom: 'UTF8' with: [
				spec loads: #('SMTPMail' ) ].
		spec 
			package: 'Grease-Core' with: [
				spec 
					requires: #('GsCore' );
					includes: #('Grease-GemStone-Core' ). ];
			package: 'Grease-Tests-Core' with: [
				spec includes: #('Grease-Tests-GemStone-Core' ). ];
			package: 'Grease-GemStone-Core' with: [
				spec requires: #('Grease-Core' 'GsCore' 'System-Digital-Signatures' 'UTF8' 'SMTPMail' ). ];
			package: 'Grease-Tests-GemStone-Core' with: [
				spec requires: #('Grease-Tests-Core' ). ].].

	spec for: #'gs2.3.x' do: [
		spec 
			package: 'Grease-GemStone-Core' with: [
				spec includes: #('Grease-GemStone230-Core' ). ];
			package: 'Grease-GemStone230-Core' with: [
				spec requires: #('Grease-GemStone-Core' ). ].].

	spec for: #'gs2.4.x' do: [
		spec 
			package: 'Grease-GemStone-Core' with: [
				spec includes: #('Grease-GemStone240-Core' ). ];
			package: 'Grease-GemStone240-Core' with: [
				spec requires: #('Grease-GemStone-Core' ). ].].

	spec for: #'gs3.x' do: [
		spec 
			package: 'Grease-GemStone-Core' with: [
				spec includes: #('Grease-GemStone300-Core' ). ];
			package: 'Grease-GemStone300-Core' with: [
				spec requires: #('Grease-GemStone-Core' ). ].].
! !

!ConfigurationOfGrease methodsFor: 'baselines' stamp: 'DaleHenrichs 2/10/2011 11:22'!
baseline104: spec
	<version: '1.0.4-baseline'>

	spec for: #'common' do: [
		spec blessing: #'baseline'.
		spec description: ''.
		spec repository: 'http://www.squeaksource.com/Seaside30'.
		spec 
			package: 'Grease-Core';
			package: 'Grease-Tests-Core' with: [
				spec requires: #('Grease-Core' ). ].
		spec 
			group: 'Core' with: #('Grease-Core' );
			group: 'Core Tests' with: #('Grease-Tests-Core' );
			group: 'Slime' with: #('Core' );
			group: 'Slime Tests' with: #('Core Tests' );
			group: 'Tests' with: #('Core Tests' 'Slime Tests' );
			group: 'default' with: #('Slime' ).].

	spec for: #'squeakCommon' do: [
		spec 
			package: 'Grease-Core' with: [
				spec includes: #('Grease-Pharo-Core' ). ];
			package: 'Grease-Tests-Core' with: [
				spec includes: #('Grease-Tests-Pharo-Core' ). ];
			package: 'Grease-Pharo-Core' with: [
				spec requires: #('Grease-Core' ). ];
			package: 'Grease-Tests-Pharo-Core' with: [
				spec requires: #('Grease-Tests-Core' ). ].].

	spec for: #'pharo' do: [
		spec project: 'Refactoring-Core' with: [
				spec
					className: 'ConfigurationOfRefactoringBrowser';
					versionString: #'stable';
					loads: #('Core' );
					repository: 'http://www.squeaksource.com/MetacelloRepository' ].
		spec 
			package: 'Grease-Slime' with: [
				spec requires: #('Refactoring-Core' 'Grease-Core' ). ];
			package: 'Grease-Tests-Slime' with: [
				spec requires: #('Grease-Slime' ). ].
		spec 
			group: 'Slime' with: #('Grease-Slime' );
			group: 'Slime Tests' with: #('Grease-Tests-Slime' ).].

	spec for: #'GreaseForPharo1.0' do: [
		spec 
			package: 'Grease-Pharo-Core' with: [
				spec includes: #('Grease-Pharo10-Core' ). ];
			package: 'Grease-Pharo10-Core'.].

	spec for: #'gemstone' do: [
		spec repository: 'http://seaside.gemstone.com/ss/Seaside30'.
		spec 
			project: 'GsCore' with: [
				spec
					className: 'ConfigurationOfGsCore';
					versionString: #'stable';
					repository: 'http://seaside.gemstone.com/ss/MetacelloRepository' ];
			project: 'UTF8' with: [
				spec
					className: 'ConfigurationOfGsMisc';
					versionString: #'stable';
					loads: #('Utf8Encoding' );
					repository: 'http://seaside.gemstone.com/ss/MetacelloRepository' ];
			project: 'System-Digital-Signatures' copyFrom: 'UTF8' with: [
				spec loads: #('System-Digital-Signatures' ) ];
			project: 'SMTPMail' copyFrom: 'UTF8' with: [
				spec loads: #('SMTPMail' ) ].
		spec 
			package: 'Grease-Core' with: [
				spec 
					requires: #('GsCore' );
					includes: #('Grease-GemStone-Core' ). ];
			package: 'Grease-Tests-Core' with: [
				spec includes: #('Grease-Tests-GemStone-Core' ). ];
			package: 'Grease-GemStone-Core' with: [
				spec requires: #('Grease-Core' 'GsCore' 'System-Digital-Signatures' 'UTF8' 'SMTPMail' ). ];
			package: 'Grease-Tests-GemStone-Core' with: [
				spec requires: #('Grease-Tests-Core' ). ].].

	spec for: #'gs2.3.x' do: [
		spec 
			package: 'Grease-GemStone-Core' with: [
				spec includes: #('Grease-GemStone230-Core' ). ];
			package: 'Grease-GemStone230-Core' with: [
				spec requires: #('Grease-GemStone-Core' ). ].].

	spec for: #'gs2.4.x' do: [
		spec 
			package: 'Grease-GemStone-Core' with: [
				spec includes: #('Grease-GemStone240-Core' ). ];
			package: 'Grease-GemStone240-Core' with: [
				spec requires: #('Grease-GemStone-Core' ). ].].

	spec for: #'gs3.x' do: [
		spec 
			package: 'Grease-GemStone-Core' with: [
				spec includes: #('Grease-GemStone300-Core' ). ];
			package: 'Grease-GemStone300-Core' with: [
				spec requires: #('Grease-GemStone-Core' ). ].].
! !

!ConfigurationOfGrease methodsFor: 'baselines' stamp: 'dkh 10/14/2011 17:01'!
baseline1061: spec
	<version: '1.0.6.1-baseline'>

	spec for: #'common' do: [
		spec blessing: #'baseline'.
		spec description: ''.
		spec repository: 'http://www.squeaksource.com/Seaside30'.
		spec 
			package: 'Grease-Core';
			package: 'Grease-Tests-Core' with: [
				spec requires: #('Grease-Core' ). ].
		spec 
			group: 'Core' with: #('Grease-Core' );
			group: 'Core Tests' with: #('Grease-Tests-Core' );
			group: 'Slime' with: #('Core' );
			group: 'Slime Tests' with: #('Core Tests' );
			group: 'Tests' with: #('Core Tests' 'Slime Tests' );
			group: 'default' with: #('Slime' ).].

	spec for: #'squeakCommon' do: [
		spec 
			package: 'Grease-Core' with: [
				spec includes: #('Grease-Pharo-Core' ). ];
			package: 'Grease-Tests-Core' with: [
				spec includes: #('Grease-Tests-Pharo-Core' ). ];
			package: 'Grease-Pharo-Core' with: [
				spec requires: #('Grease-Core' ). ];
			package: 'Grease-Tests-Pharo-Core' with: [
				spec requires: #('Grease-Tests-Core' ). ].].

	spec for: #'pharo' do: [
		spec project: 'Refactoring-Core' with: [
				spec
					className: 'ConfigurationOfRefactoringBrowser';
					versionString: #'stable';
					loads: #('Core' );
					repository: 'http://www.squeaksource.com/MetacelloRepository' ].
		spec 
			package: 'Grease-Slime' with: [
				spec requires: #('Refactoring-Core' 'Grease-Core' ). ];
			package: 'Grease-Tests-Slime' with: [
				spec requires: #('Grease-Slime' ). ].
		spec 
			group: 'Slime' with: #('Grease-Slime' );
			group: 'Slime Tests' with: #('Grease-Tests-Slime' ).].

	spec for: #'GreaseForPharo1.0' do: [
		spec 
			package: 'Grease-Pharo-Core' with: [
				spec includes: #('Grease-Pharo10-Core' ). ];
			package: 'Grease-Pharo10-Core'.].

	spec for: #'gemstone' do: [
		spec repository: 'http://seaside.gemstone.com/ss/Seaside30'.
		spec 
			project: 'GsCore' with: [
				spec
					className: 'ConfigurationOfGsCore';
					versionString: #'stable';
					repository: 'http://seaside.gemstone.com/ss/MetacelloRepository' ];
			project: 'UTF8' with: [
				spec
					className: 'ConfigurationOfGsMisc';
					versionString: #'stable';
					loads: #('Utf8Encoding' );
					repository: 'http://seaside.gemstone.com/ss/MetacelloRepository' ];
			project: 'System-Digital-Signatures' copyFrom: 'UTF8' with: [
				spec loads: #('System-Digital-Signatures' ) ];
			project: 'SMTPMail' copyFrom: 'UTF8' with: [
				spec loads: #('SMTPMail' ) ].
		spec 
			package: 'Grease-Core' with: [
				spec 
					requires: #('GsCore' );
					includes: #('Grease-GemStone-Core' ). ];
			package: 'Grease-Tests-Core' with: [
				spec includes: #('Grease-Tests-GemStone-Core' ). ];
			package: 'Grease-GemStone-Core' with: [
				spec requires: #('Grease-Core' 'GsCore' 'System-Digital-Signatures' 'UTF8' 'SMTPMail' ). ];
			package: 'Grease-Tests-GemStone-Core' with: [
				spec requires: #('Grease-Tests-Core' ). ].].

	spec for: #'gs2.x' do: [
		spec 
			package: 'Grease-GemStone-Core' with: [
				spec includes: #('Grease-GemStone200-Core' ). ];
			package: 'Grease-GemStone200-Core' with: [
				spec requires: #('Grease-GemStone-Core' ). ].].

	spec for: #'gs2.3.x' do: [
		spec 
			package: 'Grease-GemStone-Core' with: [
				spec includes: #('Grease-GemStone230-Core' ). ];
			package: 'Grease-GemStone230-Core' with: [
				spec requires: #('Grease-GemStone-Core' ). ].].

	spec for: #'gs2.4.x' do: [
		spec 
			package: 'Grease-GemStone-Core' with: [
				spec includes: #('Grease-GemStone240-Core' ). ];
			package: 'Grease-GemStone240-Core' with: [
				spec requires: #('Grease-GemStone-Core' ). ].].

	spec for: #'gs3.x' do: [
		spec 
			package: 'Grease-GemStone-Core' with: [
				spec includes: #('Grease-GemStone300-Core' ). ];
			package: 'Grease-GemStone300-Core' with: [
				spec requires: #('Grease-GemStone-Core' ). ].].
! !

!ConfigurationOfGrease methodsFor: 'baselines' stamp: 'dkh 4/27/2012 10:14'!
baseline1071: spec
	<version: '1.0.7.1-baseline'>

	spec for: #'common' do: [
		spec blessing: #'baseline'.
		spec description: ''.
		spec repository: 'http://www.squeaksource.com/Seaside30'.
		spec 
			package: 'Grease-Core';
			package: 'Grease-Tests-Core' with: [
				spec requires: #('Grease-Core' ). ].
		spec 
			group: 'Core' with: #('Grease-Core' );
			group: 'Core Tests' with: #('Grease-Tests-Core' );
			group: 'Slime' with: #('Core' );
			group: 'Slime Tests' with: #('Core Tests' );
			group: 'Tests' with: #('Core Tests' 'Slime Tests' );
			group: 'default' with: #('Slime' ).].

	spec for: #'squeakCommon' do: [
		spec 
			package: 'Grease-Core' with: [
				spec includes: #('Grease-Pharo-Core' ). ];
			package: 'Grease-Tests-Core' with: [
				spec includes: #('Grease-Tests-Pharo-Core' ). ];
			package: 'Grease-Pharo-Core' with: [
				spec requires: #('Grease-Core' ). ];
			package: 'Grease-Tests-Pharo-Core' with: [
				spec requires: #('Grease-Tests-Core' ). ].].

	spec for: #'pharo1.x' do: [
		spec project: 'Refactoring-Core' with: [
				spec
					className: 'ConfigurationOfRefactoringBrowser';
					versionString: #'stable';
					loads: #('Core' );
					repository: 'http://www.squeaksource.com/MetacelloRepository' ].
		spec 
			package: 'Grease-Slime' with: [
				spec requires: #('Refactoring-Core' 'Grease-Core' ). ];
			package: 'Grease-Tests-Slime' with: [
				spec requires: #('Grease-Slime' ). ].
		spec 
			group: 'Slime' with: #('Grease-Slime' );
			group: 'Slime Tests' with: #('Grease-Tests-Slime' ).].

	spec for: #'pharo1.x' do: [
		spec 
			package: 'Grease-Pharo-Core' with: [
				spec includes: #('Grease-Pharo13-Core' ). ];
			package: 'Grease-Pharo13-Core' ].

	spec for: #'squeak' do: [
		spec 
			package: 'Grease-Pharo-Core' with: [
				spec includes: #('Grease-Pharo13-Core' ). ];
			package: 'Grease-Pharo13-Core' ].

	spec for: #'GreaseForPharo1.0' do: [
		spec 
			package: 'Grease-Pharo-Core' with: [
				spec includes: #('Grease-Pharo10-Core' ). ];
			package: 'Grease-Pharo10-Core'.].

	spec for: #'gemstone' do: [
		spec repository: 'http://seaside.gemstone.com/ss/Seaside30'.
		spec 
			project: 'GsCore' with: [
				spec
					className: 'ConfigurationOfGsCore';
					versionString: #'stable';
					repository: 'http://seaside.gemstone.com/ss/MetacelloRepository' ];
			project: 'UTF8' with: [
				spec
					className: 'ConfigurationOfGsMisc';
					versionString: #'stable';
					loads: #('Utf8Encoding' );
					repository: 'http://seaside.gemstone.com/ss/MetacelloRepository' ];
			project: 'System-Digital-Signatures' copyFrom: 'UTF8' with: [
				spec loads: #('System-Digital-Signatures' ) ];
			project: 'SMTPMail' copyFrom: 'UTF8' with: [
				spec loads: #('SMTPMail' ) ].
		spec 
			package: 'Grease-Core' with: [
				spec 
					requires: #('GsCore' );
					includes: #('Grease-GemStone-Core' ). ];
			package: 'Grease-Tests-Core' with: [
				spec includes: #('Grease-Tests-GemStone-Core' ). ];
			package: 'Grease-GemStone-Core' with: [
				spec requires: #('Grease-Core' 'GsCore' 'System-Digital-Signatures' 'UTF8' 'SMTPMail' ). ];
			package: 'Grease-Tests-GemStone-Core' with: [
				spec requires: #('Grease-Tests-Core' ). ].].

	spec for: #'gs2.x' do: [
		spec 
			package: 'Grease-GemStone-Core' with: [
				spec includes: #('Grease-GemStone200-Core' ). ];
			package: 'Grease-GemStone200-Core' with: [
				spec requires: #('Grease-GemStone-Core' ). ].].

	spec for: #'gs2.3.x' do: [
		spec 
			package: 'Grease-GemStone-Core' with: [
				spec includes: #('Grease-GemStone230-Core' ). ];
			package: 'Grease-GemStone230-Core' with: [
				spec requires: #('Grease-GemStone-Core' ). ].].

	spec for: #'gs2.4.x' do: [
		spec 
			package: 'Grease-GemStone-Core' with: [
				spec includes: #('Grease-GemStone240-Core' ). ];
			package: 'Grease-GemStone240-Core' with: [
				spec requires: #('Grease-GemStone-Core' ). ].].

	spec for: #'gs3.x' do: [
		spec 
			package: 'Grease-GemStone-Core' with: [
				spec includes: #('Grease-GemStone300-Core' ). ];
			package: 'Grease-GemStone300-Core' with: [
				spec requires: #('Grease-GemStone-Core' ). ].].
! !

!ConfigurationOfGrease methodsFor: 'baselines' stamp: 'DaleHenrichs 10/9/2010 11:40'!
baseline10: spec 
	<version: '1.0-baseline'>

	spec for: #common do: [
		spec blessing: #baseline.
		spec repository: 'http://www.squeaksource.com/Seaside30'.
		spec
			package: 'Grease-Core';
			package: 'Grease-Tests-Core' 
				with: [ spec requires: #('Grease-Core' ). ];
			yourself.
		spec
			group: 'Core' with: #('Grease-Core');
			group: 'Core Tests' with: #('Grease-Tests-Core');
			group: 'Slime' with: #('Core');
			group: 'Slime Tests' with: #('Core Tests');
			group: 'Tests' with: #('Core Tests' 'Slime Tests');
			group: 'default' with: #('Slime');
			yourself. ].

	spec for: #squeakCommon do: [
		spec
			package: 'Grease-Core' 
				with: [ spec includes: #('Grease-Pharo-Core' ) ];
			package: 'Grease-Tests-Core' 
				with: [ spec includes: #('Grease-Tests-Pharo-Core' ). ];
			package: 'Grease-Pharo-Core' 
				with: [ spec requires: #('Grease-Core' ) ];
			package: 'Grease-Tests-Pharo-Core' 
				with: [ spec requires: #('Grease-Tests-Core') ];					
			yourself. ].

	spec for: #pharo do: [
		spec
			project: 'Refactoring-Core' with: [
				spec
					className: 'ConfigurationOfRefactoringBrowser';
					versionString: '1.2-baseline';
					loads: #('Refactoring-Core' );
					file: 'ConfigurationOfRefactoringBrowser';
					repository: 'http://www.squeaksource.com/MetacelloRepository' ];
			yourself.
		spec
			package: 'Grease-Slime' 
				with: [ spec requires: #('Refactoring-Core' 'Grease-Core' ) ];
			package: 'Grease-Tests-Slime' 
				with: [ spec requires: #('Grease-Slime') ];					
			yourself.
		spec
			group: 'Slime' with: #('Grease-Slime');
			group: 'Slime Tests' with: #('Grease-Tests-Slime');
			yourself. ].
	spec for: #'GreaseForPharo1.0' do: [
		spec
			package: 'Grease-Pharo-Core'
				with: [ spec includes: #('Grease-Pharo10-Core' ) ];
			package: 'Grease-Pharo10-Core';
			yourself.].
	spec for: #gemstone do: [
		spec 
			repository: 'http://seaside.gemstone.com/ss/Seaside30'.

		spec 
			project: 'GsCore' with: [
				spec
					className: 'ConfigurationOfGsCore';
					versionString: '0.239-baseline';
					file: 'ConfigurationOfGsCore';
					repository: 'http://seaside.gemstone.com/ss/MetacelloRepository' ];
			project: 'UTF8' with: [
				spec
					className: 'ConfigurationOfGsMisc';
					versionString: '0.236-baseline';
					loads: #('Utf8Encoding' );
					file: 'ConfigurationOfGsMisc';
					repository: 'http://seaside.gemstone.com/ss/MetacelloRepository' ];
			project: 'System-Digital-Signatures'
				copyFrom: 'UTF8'
				with: [ spec loads: #('System-Digital-Signatures' ) ];
			project: 'SMTPMail'
				copyFrom: 'UTF8'
				with: [ spec loads: #('SMTPMail' ) ];			
			yourself.

		spec
			package: 'Grease-Core' 
				with: [ spec includes: #('Grease-GemStone-Core' ) ];
			package: 'Grease-Tests-Core' 
				with: [ spec includes: #('Grease-Tests-GemStone-Core' ). ];
			package: 'Grease-GemStone-Core' 
				with: [ spec requires: #('Grease-Core' 'GsCore' 'System-Digital-Signatures' 'UTF8' 'SMTPMail' ) ];
			package: 'Grease-Tests-GemStone-Core' 
				with: [ spec requires: #('Grease-Tests-Core' ) ];
			yourself. ].

	spec for: #'gs2.3.x' do: [
		spec 
			package: 'Grease-GemStone-Core' 
				with: [ spec includes: #('Grease-GemStone230-Core' ) ];
			package: 'Grease-GemStone230-Core' 
				with: [ spec requires: #('Grease-GemStone-Core' ) ];
			yourself. ].
	spec for: #'gs2.4.x' do: [
		spec 
			package: 'Grease-GemStone-Core' 
				with: [ spec includes: #('Grease-GemStone240-Core' ) ];
			package: 'Grease-GemStone240-Core' 
				with: [ spec requires: #('Grease-GemStone-Core' ) ];
			yourself. ].
	spec for: #'gs3.x' do: [
		spec 
			package: 'Grease-GemStone-Core' 
				with: [ spec includes: #('Grease-GemStone300-Core' ) ];
			package: 'Grease-GemStone300-Core' 
				with: [ spec requires: #('Grease-GemStone-Core' ) ];
			yourself. ].
! !

!ConfigurationOfGrease methodsFor: 'baselines' stamp: 'dkh 01/06/2010 11:33'!
baseline10alpha1: spec 
	<version: '1.0-alpha1-baseline'>

	spec for: #common do: [
		spec blessing: #baseline.
		spec repository: 'http://www.squeaksource.com/Seaside30'.
		spec
			package: 'Grease-Core';
			package: 'Grease-Tests-Core' 
				with: [ spec requires: #('Grease-Core' ). ];
			yourself. ].

	spec for: #squeakCommon do: [
		spec
			package: 'Grease-Core' 
				with: [ spec includes: #('Grease-Pharo-Core' ) ];
			package: 'Grease-Tests-Core' 
				with: [ spec includes: #('Grease-Tests-Pharo-Core' ). ];
			package: 'Grease-Pharo-Core' 
				with: [ spec requires: #('Grease-Core' ) ];
			package: 'Grease-Tests-Pharo-Core' 
				with: [ spec requires: #('Grease-Tests-Core') ];					
			yourself. ].
	spec for: #gemstone do: [
		spec 
			repository: 'http://seaside.gemstone.com/ss/Seaside30'.

		spec 
			project: 'UTF8' with: [
				spec
					className: 'ConfigurationOfGsMisc';
					versionString: '0.233';
					loads: #('Utf8Encoding' );
					file: 'ConfigurationOfGsMisc';
					repository: 'http://seaside.gemstone.com/ss/GLASSproject' ];
			project: 'System-Digital-Signatures'
				copyFrom: 'UTF8'
				with: [ spec loads: #('System-Digital-Signatures' ) ];
			yourself.

		spec
			package: 'Grease-Core' 
				with: [ spec includes: #('Grease-GemStone-Core' ) ];
			package: 'Grease-Tests-Core' 
				with: [ spec includes: #('Grease-Tests-GemStone-Core' ). ];
			package: 'Grease-GemStone-Core' 
				with: [ spec requires: #('Grease-Core' 'System-Digital-Signatures' 'UTF8' ) ];
			package: 'Grease-Tests-GemStone-Core' 
				with: [ spec requires: #('Grease-Tests-Core' ) ];
			yourself. ].
! !

!ConfigurationOfGrease methodsFor: 'baselines' stamp: 'dkh 11/23/2009 15:11'!
baseline10alpha2: spec 
	<version: '1.0-alpha2-baseline' imports: #('1.0-alpha1-baseline' )>

	spec for: #gemstone do: [
		spec
			project: 'SMTPMail'
				copyFrom: 'UTF8'
				with: [ spec loads: #('SMTPMail' ) ];			
			yourself.
		spec 
			package: 'Grease-GemStone-Core' 
				with: [ spec requires: #('SMTPMail' ) ];
			yourself. ].
	spec for: #'gs2.3.x' do: [
		spec 
			package: 'Grease-GemStone-Core' 
				with: [ spec includes: #('Grease-GemStone230-Core' ) ];
			package: 'Grease-GemStone230-Core' 
				with: [ spec requires: #('Grease-GemStone-Core' ) ];
			yourself. ].
! !

!ConfigurationOfGrease methodsFor: 'baselines' stamp: 'dkh 1/27/2010 15:45'!
baseline10alpha5: spec 
	<version: '1.0-alpha5-baseline'>

	spec for: #common do: [
		spec blessing: #baseline.
		spec repository: 'http://www.squeaksource.com/Seaside30'.
		spec
			package: 'Grease-Core';
			package: 'Grease-Tests-Core' 
				with: [ spec requires: #('Grease-Core' ). ];
			yourself.
		spec
			group: 'default' with: #('Core');
			group: 'Core' with: #('Grease-Core');
			group: 'Tests' with: #('Grease-Tests-Core');
			yourself. ].

	spec for: #squeakCommon do: [
		spec
			package: 'Grease-Core' 
				with: [ spec includes: #('Grease-Pharo-Core' ) ];
			package: 'Grease-Tests-Core' 
				with: [ spec includes: #('Grease-Tests-Pharo-Core' ). ];
			package: 'Grease-Pharo-Core' 
				with: [ spec requires: #('Grease-Core' ) ];
			package: 'Grease-Tests-Pharo-Core' 
				with: [ spec requires: #('Grease-Tests-Core') ];					
			yourself.
		spec
			group: 'Core' with: #('Grease-Pharo-Core');
			group: 'Tests' with: #('Grease-Tests-Pharo-Core');
			yourself. ].

	spec for: #pharo do: [
		spec
			project: 'Refactoring-Core' with: [
				spec
					className: 'ConfigurationOfRefactoringBrowser';
					versionString: '1.1-baseline';
					loads: #('Refactoring-Core' );
					file: 'ConfigurationOfRefactoringBrowser';
					repository: 'http://www.squeaksource.com/MetacelloRepository' ];
			yourself.
		spec
			package: 'Grease-Slime' 
				with: [ spec requires: #('Refactoring-Core' 'Grease-Core' ) ];
			package: 'Grease-Tests-Slime' 
				with: [ spec requires: #('Grease-Slime') ];					
			yourself.
		spec
			group: 'Core' with: #('Grease-Slime');
			group: 'Tests' with: #('Grease-Tests-Slime');
			yourself. ].
	
	spec for: #gemstone do: [
		spec 
			repository: 'http://seaside.gemstone.com/ss/Seaside30'.

		spec 
			project: 'UTF8' with: [
				spec
					className: 'ConfigurationOfGsMisc';
					versionString: '0.233';
					loads: #('Utf8Encoding' );
					file: 'ConfigurationOfGsMisc';
					repository: 'http://seaside.gemstone.com/ss/GLASSproject' ];
			project: 'System-Digital-Signatures'
				copyFrom: 'UTF8'
				with: [ spec loads: #('System-Digital-Signatures' ) ];
			project: 'SMTPMail'
				copyFrom: 'UTF8'
				with: [ spec loads: #('SMTPMail' ) ];			
			yourself.

		spec
			package: 'Grease-Core' 
				with: [ spec includes: #('Grease-GemStone-Core' ) ];
			package: 'Grease-Tests-Core' 
				with: [ spec includes: #('Grease-Tests-GemStone-Core' ). ];
			package: 'Grease-GemStone-Core' 
				with: [ spec requires: #('Grease-Core' 'System-Digital-Signatures' 'UTF8' 'SMTPMail' ) ];
			package: 'Grease-Tests-GemStone-Core' 
				with: [ spec requires: #('Grease-Tests-Core' ) ];
			yourself.
		spec
			group: 'Core' with: #('Grease-GemStone-Core');
			group: 'Tests' with: #('Grease-Tests-GemStone-Core');
			yourself. ].

	spec for: #'gs2.3.x' do: [
		spec 
			package: 'Grease-GemStone-Core' 
				with: [ spec includes: #('Grease-GemStone230-Core' ) ];
			package: 'Grease-GemStone230-Core' 
				with: [ spec requires: #('Grease-GemStone-Core' ) ];
			yourself.
		spec
			group: 'Core' with: #('Grease-GemStone230-Core');
			yourself. ].
! !

!ConfigurationOfGrease methodsFor: 'baselines' stamp: 'DaleHenrichs 3/29/2010 11:12'!
baseline10alpha7: spec 
	<version: '1.0-alpha7-baseline'>

	spec for: #common do: [
		spec blessing: #baseline.
		spec repository: 'http://www.squeaksource.com/Seaside30'.
		spec
			package: 'Grease-Core';
			package: 'Grease-Tests-Core' 
				with: [ spec requires: #('Grease-Core' ). ];
			yourself.
		spec
			group: 'default' with: #('Core');
			group: 'Core' with: #('Grease-Core');
			group: 'Tests' with: #('Grease-Tests-Core');
			yourself. ].

	spec for: #squeakCommon do: [
		spec
			package: 'Grease-Core' 
				with: [ spec includes: #('Grease-Pharo-Core' ) ];
			package: 'Grease-Tests-Core' 
				with: [ spec includes: #('Grease-Tests-Pharo-Core' ). ];
			package: 'Grease-Pharo-Core' 
				with: [ spec requires: #('Grease-Core' ) ];
			package: 'Grease-Tests-Pharo-Core' 
				with: [ spec requires: #('Grease-Tests-Core') ];					
			yourself.
		spec
			group: 'Core' with: #('Grease-Pharo-Core');
			group: 'Tests' with: #('Grease-Tests-Pharo-Core');
			yourself. ].

	spec for: #pharo do: [
		spec
			project: 'Refactoring-Core' with: [
				spec
					className: 'ConfigurationOfRefactoringBrowser';
					versionString: '1.2-baseline';
					loads: #('Refactoring-Core' );
					file: 'ConfigurationOfRefactoringBrowser';
					repository: 'http://www.squeaksource.com/MetacelloRepository' ];
			yourself.
		spec
			package: 'Grease-Slime' 
				with: [ spec requires: #('Refactoring-Core' 'Grease-Core' ) ];
			package: 'Grease-Tests-Slime' 
				with: [ spec requires: #('Grease-Slime') ];					
			yourself.
		spec
			group: 'Core' with: #('Grease-Slime');
			group: 'Tests' with: #('Grease-Tests-Slime');
			yourself. ].
	
	spec for: #gemstone do: [
		spec 
			repository: 'http://seaside.gemstone.com/ss/Seaside30'.

		spec 
			project: 'UTF8' with: [
				spec
					className: 'ConfigurationOfGsMisc';
					versionString: '0.233';
					loads: #('Utf8Encoding' );
					file: 'ConfigurationOfGsMisc';
					repository: 'http://seaside.gemstone.com/ss/GLASSproject' ];
			project: 'System-Digital-Signatures'
				copyFrom: 'UTF8'
				with: [ spec loads: #('System-Digital-Signatures' ) ];
			project: 'SMTPMail'
				copyFrom: 'UTF8'
				with: [ spec loads: #('SMTPMail' ) ];			
			yourself.

		spec
			package: 'Grease-Core' 
				with: [ spec includes: #('Grease-GemStone-Core' ) ];
			package: 'Grease-Tests-Core' 
				with: [ spec includes: #('Grease-Tests-GemStone-Core' ). ];
			package: 'Grease-GemStone-Core' 
				with: [ spec requires: #('Grease-Core' 'System-Digital-Signatures' 'UTF8' 'SMTPMail' ) ];
			package: 'Grease-Tests-GemStone-Core' 
				with: [ spec requires: #('Grease-Tests-Core' ) ];
			yourself.
		spec
			group: 'Core' with: #('Grease-GemStone-Core');
			group: 'Tests' with: #('Grease-Tests-GemStone-Core');
			yourself. ].

	spec for: #'gs2.3.x' do: [
		spec 
			package: 'Grease-GemStone-Core' 
				with: [ spec includes: #('Grease-GemStone230-Core' ) ];
			package: 'Grease-GemStone230-Core' 
				with: [ spec requires: #('Grease-GemStone-Core' ) ];
			yourself.
		spec
			group: 'Core' with: #('Grease-GemStone230-Core');
			yourself. ].
! !

!ConfigurationOfGrease methodsFor: 'baselines' stamp: 'DaleHenrichs 08/12/2010 10:09'!
baseline10alpha93: spec 
	<version: '1.0-alpha9.3-baseline'>

	spec for: #common do: [
		spec blessing: #baseline.
		spec repository: 'http://www.squeaksource.com/Seaside30'.
		spec
			package: 'Grease-Core';
			package: 'Grease-Tests-Core' 
				with: [ spec requires: #('Grease-Core' ). ];
			yourself.
		spec
			group: 'Core' with: #('Grease-Core');
			group: 'Core Tests' with: #('Grease-Tests-Core');
			group: 'Slime' with: #('Core');
			group: 'Slime Tests' with: #('Core Tests');
			group: 'Tests' with: #('Core Tests' 'Slime Tests');
			group: 'default' with: #('Slime');
			yourself. ].

	spec for: #squeakCommon do: [
		spec
			package: 'Grease-Core' 
				with: [ spec includes: #('Grease-Pharo-Core' ) ];
			package: 'Grease-Tests-Core' 
				with: [ spec includes: #('Grease-Tests-Pharo-Core' ). ];
			package: 'Grease-Pharo-Core' 
				with: [ spec requires: #('Grease-Core' ) ];
			package: 'Grease-Tests-Pharo-Core' 
				with: [ spec requires: #('Grease-Tests-Core') ];					
			yourself. ].

	spec for: #pharo do: [
		spec
			project: 'Refactoring-Core' with: [
				spec
					className: 'ConfigurationOfRefactoringBrowser';
					versionString: '1.2-baseline';
					loads: #('Refactoring-Core' );
					file: 'ConfigurationOfRefactoringBrowser';
					repository: 'http://www.squeaksource.com/MetacelloRepository' ];
			yourself.
		spec
			package: 'Grease-Slime' 
				with: [ spec requires: #('Refactoring-Core' 'Grease-Core' ) ];
			package: 'Grease-Tests-Slime' 
				with: [ spec requires: #('Grease-Slime') ];					
			yourself.
		spec
			group: 'Slime' with: #('Grease-Slime');
			group: 'Slime Tests' with: #('Grease-Tests-Slime');
			yourself. ].
	
	spec for: #gemstone do: [
		spec 
			repository: 'http://seaside.gemstone.com/ss/Seaside30'.

		spec 
			project: 'GsCore' with: [
				spec
					className: 'ConfigurationOfGsCore';
					versionString: '0.239-baseline';
					file: 'ConfigurationOfGsCore';
					repository: 'http://seaside.gemstone.com/ss/MetacelloRepository' ];
			project: 'UTF8' with: [
				spec
					className: 'ConfigurationOfGsMisc';
					versionString: '0.236-baseline';
					loads: #('Utf8Encoding' );
					file: 'ConfigurationOfGsMisc';
					repository: 'http://seaside.gemstone.com/ss/MetacelloRepository' ];
			project: 'System-Digital-Signatures'
				copyFrom: 'UTF8'
				with: [ spec loads: #('System-Digital-Signatures' ) ];
			project: 'SMTPMail'
				copyFrom: 'UTF8'
				with: [ spec loads: #('SMTPMail' ) ];			
			yourself.

		spec
			package: 'Grease-Core' 
				with: [ spec includes: #('Grease-GemStone-Core' ) ];
			package: 'Grease-Tests-Core' 
				with: [ spec includes: #('Grease-Tests-GemStone-Core' ). ];
			package: 'Grease-GemStone-Core' 
				with: [ spec requires: #('Grease-Core' 'GsCore' 'System-Digital-Signatures' 'UTF8' 'SMTPMail' ) ];
			package: 'Grease-Tests-GemStone-Core' 
				with: [ spec requires: #('Grease-Tests-Core' ) ];
			yourself. ].

	spec for: #'gs2.3.x' do: [
		spec 
			package: 'Grease-GemStone-Core' 
				with: [ spec includes: #('Grease-GemStone230-Core' ) ];
			package: 'Grease-GemStone230-Core' 
				with: [ spec requires: #('Grease-GemStone-Core' ) ];
			yourself. ].
! !

!ConfigurationOfGrease methodsFor: 'baselines' stamp: 'DaleHenrichs 08/12/2010 10:09'!
baseline10rc: spec 
	<version: '1.0-rc-baseline'>

	spec for: #common do: [
		spec blessing: #baseline.
		spec repository: 'http://www.squeaksource.com/Seaside30'.
		spec
			package: 'Grease-Core';
			package: 'Grease-Tests-Core' 
				with: [ spec requires: #('Grease-Core' ). ];
			yourself.
		spec
			group: 'Core' with: #('Grease-Core');
			group: 'Core Tests' with: #('Grease-Tests-Core');
			group: 'Slime' with: #('Core');
			group: 'Slime Tests' with: #('Core Tests');
			group: 'Tests' with: #('Core Tests' 'Slime Tests');
			group: 'default' with: #('Slime');
			yourself. ].

	spec for: #squeakCommon do: [
		spec
			package: 'Grease-Core' 
				with: [ spec includes: #('Grease-Pharo-Core' ) ];
			package: 'Grease-Tests-Core' 
				with: [ spec includes: #('Grease-Tests-Pharo-Core' ). ];
			package: 'Grease-Pharo-Core' 
				with: [ spec requires: #('Grease-Core' ) ];
			package: 'Grease-Tests-Pharo-Core' 
				with: [ spec requires: #('Grease-Tests-Core') ];					
			yourself. ].

	spec for: #pharo do: [
		spec
			project: 'Refactoring-Core' with: [
				spec
					className: 'ConfigurationOfRefactoringBrowser';
					versionString: '1.2-baseline';
					loads: #('Refactoring-Core' );
					file: 'ConfigurationOfRefactoringBrowser';
					repository: 'http://www.squeaksource.com/MetacelloRepository' ];
			yourself.
		spec
			package: 'Grease-Slime' 
				with: [ spec requires: #('Refactoring-Core' 'Grease-Core' ) ];
			package: 'Grease-Tests-Slime' 
				with: [ spec requires: #('Grease-Slime') ];					
			yourself.
		spec
			group: 'Slime' with: #('Grease-Slime');
			group: 'Slime Tests' with: #('Grease-Tests-Slime');
			yourself. ].
	
	spec for: #gemstone do: [
		spec 
			repository: 'http://seaside.gemstone.com/ss/Seaside30'.

		spec 
			project: 'GsCore' with: [
				spec
					className: 'ConfigurationOfGsCore';
					versionString: '0.239-baseline';
					file: 'ConfigurationOfGsCore';
					repository: 'http://seaside.gemstone.com/ss/MetacelloRepository' ];
			project: 'UTF8' with: [
				spec
					className: 'ConfigurationOfGsMisc';
					versionString: '0.236-baseline';
					loads: #('Utf8Encoding' );
					file: 'ConfigurationOfGsMisc';
					repository: 'http://seaside.gemstone.com/ss/MetacelloRepository' ];
			project: 'System-Digital-Signatures'
				copyFrom: 'UTF8'
				with: [ spec loads: #('System-Digital-Signatures' ) ];
			project: 'SMTPMail'
				copyFrom: 'UTF8'
				with: [ spec loads: #('SMTPMail' ) ];			
			yourself.

		spec
			package: 'Grease-Core' 
				with: [ spec includes: #('Grease-GemStone-Core' ) ];
			package: 'Grease-Tests-Core' 
				with: [ spec includes: #('Grease-Tests-GemStone-Core' ). ];
			package: 'Grease-GemStone-Core' 
				with: [ spec requires: #('Grease-Core' 'GsCore' 'System-Digital-Signatures' 'UTF8' 'SMTPMail' ) ];
			package: 'Grease-Tests-GemStone-Core' 
				with: [ spec requires: #('Grease-Tests-Core' ) ];
			yourself. ].

	spec for: #'gs2.3.x' do: [
		spec 
			package: 'Grease-GemStone-Core' 
				with: [ spec includes: #('Grease-GemStone230-Core' ) ];
			package: 'Grease-GemStone230-Core' 
				with: [ spec requires: #('Grease-GemStone-Core' ) ];
			yourself. ].
	spec for: #'gs2.4.x' do: [
		spec 
			package: 'Grease-GemStone-Core' 
				with: [ spec includes: #('Grease-GemStone240-Core' ) ];
			package: 'Grease-GemStone240-Core' 
				with: [ spec requires: #('Grease-GemStone-Core' ) ];
			yourself. ].
	spec for: #'gs3.x' do: [
		spec 
			package: 'Grease-GemStone-Core' 
				with: [ spec includes: #('Grease-GemStone300-Core' ) ];
			package: 'Grease-GemStone300-Core' 
				with: [ spec requires: #('Grease-GemStone-Core' ) ];
			yourself. ].
! !

!ConfigurationOfGrease methodsFor: 'baselines' stamp: 'pmm 8/28/2012 14:20'!
baseline110: spec
	<version: '1.1.0-baseline'>

	spec for: #'common' do: [
		spec blessing: #'baseline'.
		spec description: ''.
		spec repository: 'http://www.squeaksource.com/Seaside31'.
		spec 
			package: 'Grease-Core';
			package: 'Grease-Tests-Core' with: [
				spec requires: #('Grease-Core' ). ].
		spec 
			group: 'Core' with: #('Grease-Core' );
			group: 'Core Tests' with: #('Grease-Tests-Core' );
			group: 'Slime' with: #('Core' );
			group: 'Slime Tests' with: #('Core Tests' );
			group: 'Tests' with: #('Core Tests' 'Slime Tests' );
			group: 'default' with: #('Slime' ).].

	spec for: #'squeak' do: [
		spec 
			package: 'Grease-Core' with: [
				spec includes: #('Grease-Pharo-Core' ). ];
			package: 'Grease-Tests-Core' with: [
				spec includes: #('Grease-Tests-Pharo-Core' ). ];
			package: 'Grease-Pharo-Core' with: [
				spec requires: #('Grease-Core' ). ];
			package: 'Grease-Tests-Pharo-Core' with: [
				spec requires: #('Grease-Tests-Core' ) ]. ].
		
	spec for: #'pharo2.x' do: [
		spec 
			package: 'Grease-Core' with: [
				spec includes: #('Grease-Pharo20-Core' ). ];
			package: 'Grease-Tests-Core' with: [
				spec includes: #('Grease-Tests-Pharo20-Core' ). ];
			package: 'Grease-Pharo20-Core' with: [
				spec requires: #('Grease-Core' ). ];
			package: 'Grease-Tests-Pharo20-Core' with: [
				spec requires: #('Grease-Tests-Core' ) ] ].
		
	spec for: #'pharo1.x' do: [
		spec 
			package: 'Grease-Core' with: [
				spec includes: #('Grease-Pharo-Core' ). ];
			package: 'Grease-Tests-Core' with: [
				spec includes: #('Grease-Tests-Pharo-Core' ). ];
			package: 'Grease-Pharo-Core' with: [
				spec requires: #('Grease-Core' ). ];
			package: 'Grease-Tests-Pharo-Core' with: [
				spec requires: #('Grease-Tests-Core' ) ].
		
		spec
			project: 'Refactoring-Core' with: [
				spec
					className: 'ConfigurationOfRefactoringBrowser';
					versionString: #'stable';
					loads: #('Core' );
					repository: 'http://www.squeaksource.com/MetacelloRepository' ].
				
		spec 
			package: 'Grease-Slime' with: [
				spec requires: #('Refactoring-Core' 'Grease-Core' ). ];
			package: 'Grease-Tests-Slime' with: [
				spec requires: #('Grease-Slime' ). ].
		spec 
			group: 'Slime' with: #('Grease-Slime' );
			group: 'Slime Tests' with: #('Grease-Tests-Slime' ) ].

	spec for: #'pharo1.1' do: [
		spec 
			package: 'Grease-Pharo-Core' with: [
				spec includes: #('Grease-Pharo11-Core' ) ] ].
		
	spec for: #'pharo1.0' do: [
		spec 
			package: 'Grease-Pharo-Core' with: [
				spec includes: #('Grease-Pharo10-Core' 'Grease-Pharo11-Core' ) ] ].

	spec for: #'gemstone' do: [
		spec repository: 'http://seaside.gemstone.com/ss/Seaside30'.
		spec 
			project: 'GsCore' with: [
				spec
					className: 'ConfigurationOfGsCore';
					versionString: #'stable';
					repository: 'http://seaside.gemstone.com/ss/MetacelloRepository' ];
			project: 'UTF8' with: [
				spec
					className: 'ConfigurationOfGsMisc';
					versionString: #'stable';
					loads: #('Utf8Encoding' );
					repository: 'http://seaside.gemstone.com/ss/MetacelloRepository' ];
			project: 'System-Digital-Signatures' copyFrom: 'UTF8' with: [
				spec loads: #('System-Digital-Signatures' ) ];
			project: 'SMTPMail' copyFrom: 'UTF8' with: [
				spec loads: #('SMTPMail' ) ].
		spec 
			package: 'Grease-Core' with: [
				spec 
					requires: #('GsCore' );
					includes: #('Grease-GemStone-Core' ). ];
			package: 'Grease-Tests-Core' with: [
				spec includes: #('Grease-Tests-GemStone-Core' ). ];
			package: 'Grease-GemStone-Core' with: [
				spec requires: #('Grease-Core' 'GsCore' 'System-Digital-Signatures' 'UTF8' 'SMTPMail' ). ];
			package: 'Grease-Tests-GemStone-Core' with: [
				spec requires: #('Grease-Tests-Core' ). ].].

	spec for: #'gs2.x' do: [
		spec 
			package: 'Grease-GemStone-Core' with: [
				spec includes: #('Grease-GemStone200-Core' ). ];
			package: 'Grease-GemStone200-Core' with: [
				spec requires: #('Grease-GemStone-Core' ). ].].

	spec for: #'gs2.3.x' do: [
		spec 
			package: 'Grease-GemStone-Core' with: [
				spec includes: #('Grease-GemStone230-Core' ). ];
			package: 'Grease-GemStone230-Core' with: [
				spec requires: #('Grease-GemStone-Core' ). ].].

	spec for: #'gs2.4.x' do: [
		spec 
			package: 'Grease-GemStone-Core' with: [
				spec includes: #('Grease-GemStone240-Core' ). ];
			package: 'Grease-GemStone240-Core' with: [
				spec requires: #('Grease-GemStone-Core' ). ].].

	spec for: #'gs3.x' do: [
		spec 
			package: 'Grease-GemStone-Core' with: [
				spec includes: #('Grease-GemStone300-Core' ). ];
			package: 'Grease-GemStone300-Core' with: [
				spec requires: #('Grease-GemStone-Core' ). ].].
! !

!ConfigurationOfGrease methodsFor: 'symbolic versions' stamp: 'dkh 10/18/2011 21:44'!
development: spec
	<symbolicVersion: #'development'>

	spec for: #'common' version: #'notDefined'.
! !

!ConfigurationOfGrease methodsFor: 'doits' stamp: 'dkh 12/16/2009 15:40'!
initializeNewRandomCaches10alpha3

	Smalltalk at: #WAKeyGenerator ifPresent: [:cl |
		cl initialize ].! !

!ConfigurationOfGrease methodsFor: 'doits' stamp: 'NickAger 3/25/2012 05:00'!
initializeTransactionMutex1051

	(Smalltalk at: #GRGemStonePlatform) initialize.! !

!ConfigurationOfGrease methodsFor: 'accessing' stamp: 'DaleHenrichs 10/9/2010 11:35'!
project

	^ project ifNil: [ | projectAttributes |
		"Bootstrap Metacello if it is not already loaded"
		self class ensureMetacello.
		"Construct Metacello project"
		project := (Smalltalk at: #MetacelloMCProject) new.
		projectAttributes := #().
		Smalltalk at: #SystemVersion ifPresent: [:cl | | versionString |
			versionString := cl current version.
			((versionString beginsWith: 'Pharo-1.0') or: [versionString beginsWith: 'PharoCore1.0'])
				ifTrue: [ projectAttributes := projectAttributes, #(#'GreaseForPharo1.0') ] ].
		project projectAttributes:  projectAttributes.
		(Smalltalk at: #MetacelloVersionConstructor) on: self project: project.
		project loadType: #linear ]! !

!ConfigurationOfGrease methodsFor: 'symbolic versions' stamp: 'DiegoLont 3/22/2013 11:02'!
stable: spec
	<symbolicVersion: #'stable'>

	spec for: #'common' version: '1.1.1'! !

!ConfigurationOfGrease methodsFor: 'versions' stamp: 'DaleHenrichs 11/19/2010 12:32'!
version1011: spec
	<version: '1.0.1.1' imports: #('1.0.1.1-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'release'.
		spec description: '- pick up latest mcz files'.
		spec author: 'dkh'.
		spec timestamp: '11/19/2010 10:44'.
		spec 
			package: 'Grease-Core' with: 'Grease-Core-pmm.51';
			package: 'Grease-Tests-Core' with: 'Grease-Tests-Core-pmm.63'.].

	spec for: #'squeakCommon' do: [
		spec 
			package: 'Grease-Pharo-Core' with: 'Grease-Pharo-Core-pmm.32';
			package: 'Grease-Tests-Pharo-Core' with: 'Grease-Tests-Pharo-Core-pmm.8'.].

	spec for: #'pharo' do: [
		spec project: 'Refactoring-Core' with: '1.4'.
		spec 
			package: 'Grease-Slime' with: 'Grease-Slime-lr.7';
			package: 'Grease-Tests-Slime' with: 'Grease-Tests-Slime-lr.6'.].

	spec for: #'GreaseForPharo1.0' do: [
		spec package: 'Grease-Pharo10-Core' with: 'Grease-Pharo10-Core-dkh.3'.].

	spec for: #'gemstone' do: [
		spec 
			project: 'GsCore' with: '0.241';
			project: 'SMTPMail' with: '0.237';
			project: 'UTF8' with: '0.237';
			project: 'System-Digital-Signatures' with: '0.237'.
		spec 
			package: 'Grease-GemStone-Core' with: [
				spec 
					file: 'Grease-GemStone-Core-NickAger.28';
					postLoadDoIt: #'initializeNewRandomCaches10alpha3'. ];
			package: 'Grease-Tests-GemStone-Core' with: 'Grease-Tests-GemStone-Core-DaleHenrichs.8'.].

	spec for: #'gs2.3.x' do: [
		spec package: 'Grease-GemStone230-Core' with: 'Grease-GemStone230-Core-dkh.2'.].

	spec for: #'gs2.4.x' do: [
		spec package: 'Grease-GemStone240-Core' with: 'Grease-GemStone240-Core-DaleHenrichs.2'.].

	spec for: #'gs3.x' do: [
		spec package: 'Grease-GemStone300-Core' with: 'Grease-GemStone300-Core-DaleHenrichs.2'.].
! !

!ConfigurationOfGrease methodsFor: 'versions' stamp: 'DaleHenrichs 11/11/2010 13:11'!
version101: spec
	<version: '1.0.1' imports: #('1.0.1-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'release'.
		spec description: '- pick up latest mcz files'.
		spec author: 'DaleHenrichs'.
		spec timestamp: '11/08/2010 15:13:08'.
		spec 
			package: 'Grease-Core' with: 'Grease-Core-pmm.51';
			package: 'Grease-Tests-Core' with: 'Grease-Tests-Core-pmm.62'.].
	spec for: #'squeakCommon' do: [
		spec 
			package: 'Grease-Pharo-Core' with: 'Grease-Pharo-Core-pmm.31';
			package: 'Grease-Tests-Pharo-Core' with: 'Grease-Tests-Pharo-Core-pmm.8'.].
	spec for: #'pharo' do: [
		spec project: 'Refactoring-Core' with: '1.4'.
		spec 
			package: 'Grease-Slime' with: 'Grease-Slime-lr.7';
			package: 'Grease-Tests-Slime' with: 'Grease-Tests-Slime-lr.6'.].
	spec for: #'GreaseForPharo1.0' do: [
		spec package: 'Grease-Pharo10-Core' with: 'Grease-Pharo10-Core-dkh.3'.].
	spec for: #'gemstone' do: [
		spec 
			project: 'GsCore' with: '0.241';
			project: 'SMTPMail' with: '0.237';
			project: 'UTF8' with: '0.237';
			project: 'System-Digital-Signatures' with: '0.237'.
		spec 
			package: 'Grease-GemStone-Core' with: [
				spec 
					file: 'Grease-GemStone-Core-DaleHenrichs.27';
					postLoadDoIt: #'initializeNewRandomCaches10alpha3'. ];
			package: 'Grease-Tests-GemStone-Core' with: 'Grease-Tests-GemStone-Core-DaleHenrichs.8'.].
	spec for: #'gs2.3.x' do: [
		spec package: 'Grease-GemStone230-Core' with: 'Grease-GemStone230-Core-dkh.2'.].
	spec for: #'gs2.4.x' do: [
		spec package: 'Grease-GemStone240-Core' with: 'Grease-GemStone240-Core-DaleHenrichs.2'.].
	spec for: #'gs3.x' do: [
		spec package: 'Grease-GemStone300-Core' with: 'Grease-GemStone300-Core-DaleHenrichs.2'.].! !

!ConfigurationOfGrease methodsFor: 'versions' stamp: 'DaleHenrichs 12/08/2010 12:11'!
version1021: spec
	<version: '1.0.2.1' imports: #('1.0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '- ABANDONED in favor of 1.0.3'.
		spec author: 'DaleHenrichs'.
		spec timestamp: '12/03/2010 16:50:14'.
		spec 
			package: 'Grease-Core' with: 'Grease-Core-pmm.52';
			package: 'Grease-Tests-Core' with: 'Grease-Tests-Core-pmm.63'.].

	spec for: #'squeakCommon' do: [
		spec 
			package: 'Grease-Pharo-Core' with: 'Grease-Pharo-Core-pmm.32';
			package: 'Grease-Tests-Pharo-Core' with: 'Grease-Tests-Pharo-Core-pmm.8'.].

	spec for: #'pharo' do: [
		spec project: 'Refactoring-Core' with: '1.4'.
		spec 
			package: 'Grease-Slime' with: 'Grease-Slime-lr.7';
			package: 'Grease-Tests-Slime' with: 'Grease-Tests-Slime-lr.6'.].

	spec for: #'GreaseForPharo1.0' do: [
		spec package: 'Grease-Pharo10-Core' with: 'Grease-Pharo10-Core-dkh.3'.].

	spec for: #'gemstone' do: [
		spec 
			project: 'GsCore' with: '0.242';
			project: 'SMTPMail' with: '0.237';
			project: 'UTF8' with: '0.237';
			project: 'System-Digital-Signatures' with: '0.237'.
		spec 
			package: 'Grease-GemStone-Core' with: [
				spec 
					file: 'Grease-GemStone-Core-DaleHenrichs.31';
					postLoadDoIt: #'initializeNewRandomCaches10alpha3'. ];
			package: 'Grease-Tests-GemStone-Core' with: 'Grease-Tests-GemStone-Core-DaleHenrichs.11'.].

	spec for: #'gs2.3.x' do: [
		spec package: 'Grease-GemStone230-Core' with: 'Grease-GemStone230-Core-dkh.2'.].

	spec for: #'gs2.4.x' do: [
		spec package: 'Grease-GemStone240-Core' with: 'Grease-GemStone240-Core-DaleHenrichs.2'.].

	spec for: #'gs3.x' do: [
		spec package: 'Grease-GemStone300-Core' with: 'Grease-GemStone300-Core-DaleHenrichs.2'.].
! !

!ConfigurationOfGrease methodsFor: 'versions' stamp: 'pmm 11/21/2010 12:36'!
version102: spec
	<version: '1.0.2' imports: #('1.0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'release'.
		spec description: '- pick up latest mcz files'.
		spec author: 'pmm'.
		spec timestamp: '11/21/2010 12:35'.
		spec 
			package: 'Grease-Core' with: 'Grease-Core-pmm.52';
			package: 'Grease-Tests-Core' with: 'Grease-Tests-Core-pmm.63'.].

	spec for: #'squeakCommon' do: [
		spec 
			package: 'Grease-Pharo-Core' with: 'Grease-Pharo-Core-pmm.32';
			package: 'Grease-Tests-Pharo-Core' with: 'Grease-Tests-Pharo-Core-pmm.8'.].

	spec for: #'pharo' do: [
		spec project: 'Refactoring-Core' with: '1.4'.
		spec 
			package: 'Grease-Slime' with: 'Grease-Slime-lr.7';
			package: 'Grease-Tests-Slime' with: 'Grease-Tests-Slime-lr.6'.].

	spec for: #'GreaseForPharo1.0' do: [
		spec package: 'Grease-Pharo10-Core' with: 'Grease-Pharo10-Core-dkh.3'.].

	spec for: #'gemstone' do: [
		spec 
			project: 'GsCore' with: '0.241';
			project: 'SMTPMail' with: '0.237';
			project: 'UTF8' with: '0.237';
			project: 'System-Digital-Signatures' with: '0.237'.
		spec 
			package: 'Grease-GemStone-Core' with: [
				spec 
					file: 'Grease-GemStone-Core-NickAger.28';
					postLoadDoIt: #'initializeNewRandomCaches10alpha3'. ];
			package: 'Grease-Tests-GemStone-Core' with: 'Grease-Tests-GemStone-Core-DaleHenrichs.8'.].

	spec for: #'gs2.3.x' do: [
		spec package: 'Grease-GemStone230-Core' with: 'Grease-GemStone230-Core-dkh.2'.].

	spec for: #'gs2.4.x' do: [
		spec package: 'Grease-GemStone240-Core' with: 'Grease-GemStone240-Core-DaleHenrichs.2'.].

	spec for: #'gs3.x' do: [
		spec package: 'Grease-GemStone300-Core' with: 'Grease-GemStone300-Core-DaleHenrichs.2'.].
! !

!ConfigurationOfGrease methodsFor: 'versions' stamp: 'DaleHenrichs 02/08/2011 16:36'!
version1031: spec
	<version: '1.0.3.1' imports: #('1.0.3-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '- open 1.0.3.1 for development
- get Seaside3.0 running on GemStone3.0beta3
- fix Issue 212: http://code.google.com/p/glassdb/issues/detail?id=212 "FileDirectory class>>onClient switched sense" [GemStone]
- ANSI block behavior means that GemStone3.0 passes GRNumberTest>>testToDoClosures
- wait for GemStone bugs 41222 and 41223 to be fixed to pass remaining tests
- fix Issue 226:	http://code.google.com/p/glassdb/issues/detail?id=226 "Grease-Core should depend upon GsCore for #gemstone [isInfinite]"'.
		spec author: 'DaleHenrichs'.
		spec timestamp: '01/20/2011 11:01:37'.
		spec 
			package: 'Grease-Core' with: 'Grease-Core-DaleHenrichs.53';
			package: 'Grease-Tests-Core' with: 'Grease-Tests-Core-pmm.63'. ].

	spec for: #'squeakCommon' do: [
		spec 
			package: 'Grease-Pharo-Core' with: 'Grease-Pharo-Core-pmm.32';
			package: 'Grease-Tests-Pharo-Core' with: 'Grease-Tests-Pharo-Core-pmm.8'. ].

	spec for: #'pharo' do: [
		spec project: 'Refactoring-Core' with: '1.4'.
		spec 
			package: 'Grease-Slime' with: 'Grease-Slime-lr.7';
			package: 'Grease-Tests-Slime' with: 'Grease-Tests-Slime-lr.6'. ].

	spec for: #'GreaseForPharo1.0' do: [
		spec package: 'Grease-Pharo10-Core' with: 'Grease-Pharo10-Core-dkh.3'. ].

	spec for: #'gemstone' do: [
		spec 
			project: 'GsCore' with: '0.244';
			project: 'SMTPMail' with: '0.238';
			project: 'UTF8' with: '0.238';
			project: 'System-Digital-Signatures' with: '0.238'.
		spec 
			package: 'Grease-GemStone-Core' with: 'Grease-GemStone-Core-DaleHenrichs.33';
			package: 'Grease-Tests-GemStone-Core' with: 'Grease-Tests-GemStone-Core-DaleHenrichs.12'. ].

	spec for: #'gs2.3.x' do: [
		spec package: 'Grease-GemStone230-Core' with: 'Grease-GemStone230-Core-dkh.2'. ].

	spec for: #'gs2.4.x' do: [
		spec package: 'Grease-GemStone240-Core' with: 'Grease-GemStone240-Core-DaleHenrichs.2'. ].

	spec for: #'gs3.x' do: [
		spec package: 'Grease-GemStone300-Core' with: 'Grease-GemStone300-Core-DaleHenrichs.2'. ].
! !

!ConfigurationOfGrease methodsFor: 'versions' stamp: 'dkh 12/13/2010 18:17'!
version103: spec
	<version: '1.0.3' imports: #('1.0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'release'.
		spec description: '- add test coverage for GRPlatform file library support methods [GemStone]
- User ServerDirectory in Grease (for performance) [GemStone].
- fix open file descriptor leak [GemStone]
- fix Issue 166: http://code.google.com/p/glassdb/issues/detail?id=166 "discrepancy between Pharo regex and Gemstone on multiline strings [moved Ansi* streams to core GemStone]'.
		spec author: 'DaleHenrichs'.
		spec timestamp: '12/13/2010 14:45:46'.
		spec 
			package: 'Grease-Core' with: 'Grease-Core-DaleHenrichs.53';
			package: 'Grease-Tests-Core' with: 'Grease-Tests-Core-pmm.63'.].

	spec for: #'squeakCommon' do: [
		spec 
			package: 'Grease-Pharo-Core' with: 'Grease-Pharo-Core-pmm.32';
			package: 'Grease-Tests-Pharo-Core' with: 'Grease-Tests-Pharo-Core-pmm.8'.].

	spec for: #'pharo' do: [
		spec project: 'Refactoring-Core' with: '1.4'.
		spec 
			package: 'Grease-Slime' with: 'Grease-Slime-lr.7';
			package: 'Grease-Tests-Slime' with: 'Grease-Tests-Slime-lr.6'.].

	spec for: #'GreaseForPharo1.0' do: [
		spec package: 'Grease-Pharo10-Core' with: 'Grease-Pharo10-Core-dkh.3'.].

	spec for: #'gemstone' do: [
		spec 
			project: 'GsCore' with: '0.243';
			project: 'SMTPMail' with: '0.237';
			project: 'UTF8' with: '0.237';
			project: 'System-Digital-Signatures' with: '0.237'.
		spec 
			package: 'Grease-GemStone-Core' with: 'Grease-GemStone-Core-DaleHenrichs.32';
			package: 'Grease-Tests-GemStone-Core' with: 'Grease-Tests-GemStone-Core-DaleHenrichs.11'.].

	spec for: #'gs2.3.x' do: [
		spec package: 'Grease-GemStone230-Core' with: 'Grease-GemStone230-Core-dkh.2'.].

	spec for: #'gs2.4.x' do: [
		spec package: 'Grease-GemStone240-Core' with: 'Grease-GemStone240-Core-DaleHenrichs.2'.].

	spec for: #'gs3.x' do: [
		spec package: 'Grease-GemStone300-Core' with: 'Grease-GemStone300-Core-DaleHenrichs.2'.].
! !

!ConfigurationOfGrease methodsFor: 'versions' stamp: 'dkh 3/3/2011 15:28'!
version104: spec
	<version: '1.0.4' imports: #('1.0.4-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'release'.
		spec description: '- latest mcz files for 1.0.4
- fix Issue 239: using WAFastCGIAdaptor leads the false conversion of + in urls. [GemStone]
  http://code.google.com/p/glassdb/issues/detail?id=239 
- fix Issue 227: Squeak/Pharo String extensions methods don''t work on multibyte strings [GemStone]
  http://code.google.com/p/glassdb/issues/detail?id=227'.
		spec author: 'dkh'.
		spec timestamp: '2/28/2011 13:48'.
		spec 
			package: 'Grease-Core' with: 'Grease-Core-DaleHenrichs.58';
			package: 'Grease-Tests-Core' with: 'Grease-Tests-Core-pmm.65'. ].

	spec for: #'squeakCommon' do: [
		spec 
			package: 'Grease-Pharo-Core' with: 'Grease-Pharo-Core-pmm.36';
			package: 'Grease-Tests-Pharo-Core' with: 'Grease-Tests-Pharo-Core-pmm.10'. ].

	spec for: #'pharo' do: [
		spec project: 'Refactoring-Core' with: #'stable'.
		spec 
			package: 'Grease-Slime' with: 'Grease-Slime-pmm.8';
			package: 'Grease-Tests-Slime' with: 'Grease-Tests-Slime-pmm.7'. ].

	spec for: #'GreaseForPharo1.0' do: [
		spec package: 'Grease-Pharo10-Core' with: 'Grease-Pharo10-Core-dkh.3'. ].

	spec for: #'gemstone' do: [
		spec 
			project: 'GsCore' with: '0.244';
			project: 'SMTPMail' with: '0.238';
			project: 'UTF8' with: '0.238';
			project: 'System-Digital-Signatures' with: '0.238'.
		spec 
			package: 'Grease-GemStone-Core' with: 'Grease-GemStone-Core-DaleHenrichs.36';
			package: 'Grease-Tests-GemStone-Core' with: 'Grease-Tests-GemStone-Core-DaleHenrichs.13'. ].

	spec for: #'gs2.3.x' do: [
		spec package: 'Grease-GemStone230-Core' with: 'Grease-GemStone230-Core-dkh.2'. ].

	spec for: #'gs2.4.x' do: [
		spec package: 'Grease-GemStone240-Core' with: 'Grease-GemStone240-Core-DaleHenrichs.2'. ].

	spec for: #'gs3.x' do: [
		spec package: 'Grease-GemStone300-Core' with: 'Grease-GemStone300-Core-DaleHenrichs.2'. ].
! !

!ConfigurationOfGrease methodsFor: 'versions' stamp: 'dkh 08/31/2011 12:43'!
version1051: spec
	<version: '1.0.5.1' imports: #('1.0.4-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.0.5.1 (dkh.150):
- open 1.0.5.1 for development ... GemStone-specific branch aimed at bypassing use of class instance variables (etc.) to allow the GemStone 3.0 version of Seaside to run against a read only SymbolDictionary. Some class instance variables are mapped to session temps and some are mapped to user-specific storage in UserGlobals.
- refactor GRGemStonePlatform>>logError:title: and friends a bit to make it somewhat more useful
- GRGemStoneRandomProvider class instance variables mutex and generator mapped to session temps
1.0.5.1 (dkh.152):
- fix issue 290  "transactionMutex is always nil"
  http://code.google.com:9393/p/glassdb/issues/detail?id=290'.
		spec author: 'dkh'.
		spec timestamp: '08/31/2011 12:43:20'.
		spec 
			package: 'Grease-Core' with: 'Grease-Core-pmm.59';
			package: 'Grease-Tests-Core' with: 'Grease-Tests-Core-pmm.65'. ].

	spec for: #'squeakCommon' do: [
		spec 
			package: 'Grease-Pharo-Core' with: 'Grease-Pharo-Core-pmm.37';
			package: 'Grease-Tests-Pharo-Core' with: 'Grease-Tests-Pharo-Core-pmm.10'. ].

	spec for: #'pharo' do: [
		spec project: 'Refactoring-Core' with: #'stable'.
		spec 
			package: 'Grease-Slime' with: 'Grease-Slime-pmm.8';
			package: 'Grease-Tests-Slime' with: 'Grease-Tests-Slime-pmm.7'. ].

	spec for: #'GreaseForPharo1.0' do: [
		spec package: 'Grease-Pharo10-Core' with: 'Grease-Pharo10-Core-dkh.4'. ].

	spec for: #'gemstone' do: [
		spec 
			project: 'GsCore' with: '0.245';
			project: 'SMTPMail' with: '0.239';
			project: 'UTF8' with: '0.239';
			project: 'System-Digital-Signatures' with: '0.239'.
		spec 
			package: 'Grease-GemStone-Core' with: [
				spec 
					file: 'Grease-GemStone-Core-dkh.40';
					postLoadDoIt: #'initializeTransactionMutex1051'. ];
			package: 'Grease-Tests-GemStone-Core' with: 'Grease-Tests-GemStone-Core-dkh.14'. ].

	spec for: #'gs2.3.x' do: [
		spec package: 'Grease-GemStone230-Core' with: 'Grease-GemStone230-Core-dkh.2'. ].

	spec for: #'gs2.4.x' do: [
		spec package: 'Grease-GemStone240-Core' with: 'Grease-GemStone240-Core-dkh.3'. ].

	spec for: #'gs3.x' do: [
		spec package: 'Grease-GemStone300-Core' with: 'Grease-GemStone300-Core-DaleHenrichs.2'. ].
! !

!ConfigurationOfGrease methodsFor: 'versions' stamp: 'dkh 09/13/2011 16:42'!
version105: spec
	<version: '1.0.5' imports: #('1.0.4-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'release'.
		spec description: '1.0.5 (DaleHenrichs.141):
- experimental Pharo 1.2 support
- support for Iliad [GemStone]
1.0.5 (dkh.143):
- Move GRGemStonePlatformTest>>testFileLibrary to WAGemStoneFileLibraryTest ... reference to WAFileLibrary belongs in a Seaside package
1.0.5 (dkh.145):
- changes for the new Random classes available in 3.0'.
		spec author: 'dkh'.
		spec timestamp: '5/17/2011 11:10'.
		spec 
			package: 'Grease-Core' with: 'Grease-Core-pmm.59';
			package: 'Grease-Tests-Core' with: 'Grease-Tests-Core-pmm.65'. ].

	spec for: #'squeakCommon' do: [
		spec 
			package: 'Grease-Pharo-Core' with: 'Grease-Pharo-Core-pmm.37';
			package: 'Grease-Tests-Pharo-Core' with: 'Grease-Tests-Pharo-Core-pmm.10'. ].

	spec for: #'pharo' do: [
		spec project: 'Refactoring-Core' with: #'stable'.
		spec 
			package: 'Grease-Slime' with: 'Grease-Slime-pmm.8';
			package: 'Grease-Tests-Slime' with: 'Grease-Tests-Slime-pmm.7'. ].

	spec for: #'GreaseForPharo1.0' do: [
		spec package: 'Grease-Pharo10-Core' with: 'Grease-Pharo10-Core-dkh.4'. ].

	spec for: #'gemstone' do: [
		spec 
			project: 'GsCore' with: '0.244';
			project: 'SMTPMail' with: '0.238';
			project: 'UTF8' with: '0.238';
			project: 'System-Digital-Signatures' with: '0.238'.
		spec 
			package: 'Grease-GemStone-Core' with: 'Grease-GemStone-Core-DaleHenrichs.38';
			package: 'Grease-Tests-GemStone-Core' with: 'Grease-Tests-GemStone-Core-dkh.14'. ].

	spec for: #'gs2.3.x' do: [
		spec package: 'Grease-GemStone230-Core' with: 'Grease-GemStone230-Core-dkh.2'. ].

	spec for: #'gs2.4.x' do: [
		spec package: 'Grease-GemStone240-Core' with: 'Grease-GemStone240-Core-dkh.3'. ].

	spec for: #'gs3.x' do: [
		spec package: 'Grease-GemStone300-Core' with: 'Grease-GemStone300-Core-DaleHenrichs.2'. ].
! !

!ConfigurationOfGrease methodsFor: 'versions' stamp: 'dkh 10/14/2011 17:52'!
version1061: spec
	<version: '1.0.6.1' imports: #('1.0.6.1-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.0.6.1 (dkh.157):
- address GemStone2.3.x upgrade issues for GLASS 1.0-beta.8.7
1.0.6.1 (dkh.158):
- fix Issue 279: GRGemStoneRandomProvider class>>#''sessionStart'' calls TransientRandom>>#''open'' which does not exist
  http://code.google.com/p/glassdb/issues/detail?id=279
  GemStone 2.3 fix (GemStone 2.4 fixed in earlier version)
1.0.6.1 (dkh.159):
- port to GemStone 3.0.1 (#generatehardBreak changed for 3.0)
- GemStone 3.0.1 fix for Issue 130: remote breakpoints don''t work
  http://code.google.com/p/glassdb/issues/detail?id=130'.
		spec author: 'dkh'.
		spec timestamp: '10/14/2011 16:56'.
		spec 
			package: 'Grease-Core' with: 'Grease-Core-dkh.65';
			package: 'Grease-Tests-Core' with: 'Grease-Tests-Core-pmm.78'. ].

	spec for: #'squeakCommon' do: [
		spec 
			package: 'Grease-Pharo-Core' with: 'Grease-Pharo-Core-pmm.43';
			package: 'Grease-Tests-Pharo-Core' with: 'Grease-Tests-Pharo-Core-lr.13'. ].

	spec for: #'pharo' do: [
		spec project: 'Refactoring-Core' with: #'stable'.
		spec 
			package: 'Grease-Slime' with: 'Grease-Slime-lr.13';
			package: 'Grease-Tests-Slime' with: 'Grease-Tests-Slime-lr.9'. ].

	spec for: #'GreaseForPharo1.0' do: [
		spec package: 'Grease-Pharo10-Core' with: 'Grease-Pharo10-Core-dkh.4'. ].

	spec for: #'gemstone' do: [
		spec 
			project: 'GsCore' with: '0.245';
			project: 'SMTPMail' with: '0.239.1';
			project: 'UTF8' with: '0.239.1';
			project: 'System-Digital-Signatures' with: '0.239.1'.
		spec 
			package: 'Grease-GemStone-Core' with: [
				spec 
					file: 'Grease-GemStone-Core-dkh.45';
					postLoadDoIt: #'initializeTransactionMutex1051'. ];
			package: 'Grease-Tests-GemStone-Core' with: 'Grease-Tests-GemStone-Core-dkh.14'. ].

	spec for: #'gs2.x' do: [
		spec package: 'Grease-GemStone200-Core' with: 'Grease-GemStone200-Core-dkh.2'. ].

	spec for: #'gs2.3.x' do: [
		spec package: 'Grease-GemStone230-Core' with: 'Grease-GemStone230-Core-dkh.4'. ].

	spec for: #'gs2.4.x' do: [
		spec package: 'Grease-GemStone240-Core' with: 'Grease-GemStone240-Core-dkh.3'. ].

	spec for: #'gs3.x' do: [
		spec package: 'Grease-GemStone300-Core' with: 'Grease-GemStone300-Core-dkh.4'. ].
! !

!ConfigurationOfGrease methodsFor: 'versions' stamp: 'dkh 10/19/2011 11:31'!
version1062: spec
	<version: '1.0.6.2' imports: #('1.0.6.1-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'release'.
		spec description: '1.0.6.1 (dkh.157):
- address GemStone2.3.x upgrade issues for GLASS 1.0-beta.8.7
1.0.6.1 (dkh.158):
- fix Issue 279: GRGemStoneRandomProvider class>>#''sessionStart'' calls TransientRandom>>#''open'' which does not exist
  http://code.google.com/p/glassdb/issues/detail?id=279
  GemStone 2.3 fix (GemStone 2.4 fixed in earlier version)
1.0.6.1 (dkh.159):
- port to GemStone 3.0.1 (#generatehardBreak changed for 3.0)
- GemStone 3.0.1 fix for Issue 130: remote breakpoints don''t work
  http://code.google.com/p/glassdb/issues/detail?id=130
1.0.6.2 (StephaneDucasse.157): updating to renaming happening in RB :( 
								- grease-slime.14.lr and a couple of others'.
		spec author: 'StephaneDucasse'.
		spec timestamp: ' 18 October 2011'. "Date today"
		spec 
			package: 'Grease-Core' with: 'Grease-Core-lr.66';
			package: 'Grease-Tests-Core' with: 'Grease-Tests-Core-lr.79'. ].

	spec for: #'squeakCommon' do: [
		spec 
			package: 'Grease-Pharo-Core' with: 'Grease-Pharo-Core-lr.44';
			package: 'Grease-Tests-Pharo-Core' with: 'Grease-Tests-Pharo-Core-lr.13'. ].

	spec for: #'pharo' do: [
		spec project: 'Refactoring-Core' with: #'stable'.
		spec 
			package: 'Grease-Slime' with: 'Grease-Slime-lr.14';
			package: 'Grease-Tests-Slime' with: 'Grease-Tests-Slime-lr.10'. ].

	spec for: #'GreaseForPharo1.0' do: [
		spec package: 'Grease-Pharo10-Core' with: 'Grease-Pharo10-Core-dkh.4'. ].

	spec for: #'pharo1.1.x' do: [
		spec 
			package: 'Grease-Slime' with: 'Grease-Slime-lr.13';
			package: 'Grease-Tests-Slime' with: 'Grease-Tests-Slime-lr.9'. ].
	
	spec for: #'pharo1.0.x' do: [
		spec 
			package: 'Grease-Slime' with: 'Grease-Slime-lr.13';
			package: 'Grease-Tests-Slime' with: 'Grease-Tests-Slime-lr.9'. ].

	spec for: #'gemstone' do: [
		spec 
			project: 'GsCore' with: '0.245';
			project: 'SMTPMail' with: '0.239.1';
			project: 'UTF8' with: '0.239.1';
			project: 'System-Digital-Signatures' with: '0.239.1'.
		spec 
			package: 'Grease-GemStone-Core' with: [
				spec 
					file: 'Grease-GemStone-Core-dkh.45';
					postLoadDoIt: #'initializeTransactionMutex1051'. ];
			package: 'Grease-Tests-GemStone-Core' with: 'Grease-Tests-GemStone-Core-dkh.14'. ].

	spec for: #'gs2.x' do: [
		spec package: 'Grease-GemStone200-Core' with: 'Grease-GemStone200-Core-dkh.2'. ].

	spec for: #'gs2.3.x' do: [
		spec package: 'Grease-GemStone230-Core' with: 'Grease-GemStone230-Core-dkh.4'. ].

	spec for: #'gs2.4.x' do: [
		spec package: 'Grease-GemStone240-Core' with: 'Grease-GemStone240-Core-dkh.3'. ].

	spec for: #'gs3.x' do: [
		spec package: 'Grease-GemStone300-Core' with: 'Grease-GemStone300-Core-dkh.4'. ].
! !

!ConfigurationOfGrease methodsFor: 'versions' stamp: 'dkh 10/20/2011 14:52'!
version1063: spec
	<version: '1.0.6.3' imports: #('1.0.6.1-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'release'.
		spec description: '1.0.6.1 (dkh.157):
- address GemStone2.3.x upgrade issues for GLASS 1.0-beta.8.7
1.0.6.1 (dkh.158):
- fix Issue 279: GRGemStoneRandomProvider class>>#''sessionStart'' calls TransientRandom>>#''open'' which does not exist
  http://code.google.com/p/glassdb/issues/detail?id=279
  GemStone 2.3 fix (GemStone 2.4 fixed in earlier version)
1.0.6.1 (dkh.159):
- port to GemStone 3.0.1 (#generatehardBreak changed for 3.0)
- GemStone 3.0.1 fix for Issue 130: remote breakpoints don''t work
  http://code.google.com/p/glassdb/issues/detail?id=130
1.0.6.2 (StephaneDucasse.157): updating to renaming happening in RB :( 
								- grease-slime.14.lr and a couple of others
1.0.6.3 (dkh.172):
- opened for development ... continued GemStone 3.0.1 work continued from 1.0.6.1
- clean up tests when run against Minimal GLASS group'.
		spec author: 'dkh'.
		spec timestamp: '10/20/2011 14:51'. "Date today"
		spec 
			package: 'Grease-Core' with: 'Grease-Core-lr.66';
			package: 'Grease-Tests-Core' with: 'Grease-Tests-Core-lr.79'. ].

	spec for: #'squeakCommon' do: [
		spec 
			package: 'Grease-Pharo-Core' with: 'Grease-Pharo-Core-lr.44';
			package: 'Grease-Tests-Pharo-Core' with: 'Grease-Tests-Pharo-Core-lr.13'. ].

	spec for: #'pharo' do: [
		spec project: 'Refactoring-Core' with: #'stable'.
		spec 
			package: 'Grease-Slime' with: 'Grease-Slime-lr.14';
			package: 'Grease-Tests-Slime' with: 'Grease-Tests-Slime-lr.10'. ].

	spec for: #'GreaseForPharo1.0' do: [
		spec package: 'Grease-Pharo10-Core' with: 'Grease-Pharo10-Core-dkh.4'. ].

	spec for: #'pharo1.1.x' do: [
		spec 
			package: 'Grease-Slime' with: 'Grease-Slime-lr.13';
			package: 'Grease-Tests-Slime' with: 'Grease-Tests-Slime-lr.9'. ].
	
	spec for: #'pharo1.0.x' do: [
		spec 
			package: 'Grease-Slime' with: 'Grease-Slime-lr.13';
			package: 'Grease-Tests-Slime' with: 'Grease-Tests-Slime-lr.9'. ].

	spec for: #'gemstone' do: [
		spec 
			project: 'GsCore' with: '0.245';
			project: 'SMTPMail' with: '0.239.1';
			project: 'UTF8' with: '0.239.1';
			project: 'System-Digital-Signatures' with: '0.239.1'.
		spec 
			package: 'Grease-GemStone-Core' with: [
				spec 
					file: 'Grease-GemStone-Core-dkh.46';
					postLoadDoIt: #'initializeTransactionMutex1051'. ];
			package: 'Grease-Tests-GemStone-Core' with: 'Grease-Tests-GemStone-Core-dkh.14'. ].

	spec for: #'gs2.x' do: [
		spec package: 'Grease-GemStone200-Core' with: 'Grease-GemStone200-Core-dkh.2'. ].

	spec for: #'gs2.3.x' do: [
		spec package: 'Grease-GemStone230-Core' with: 'Grease-GemStone230-Core-dkh.4'. ].

	spec for: #'gs2.4.x' do: [
		spec package: 'Grease-GemStone240-Core' with: 'Grease-GemStone240-Core-dkh.3'. ].

	spec for: #'gs3.x' do: [
		spec package: 'Grease-GemStone300-Core' with: 'Grease-GemStone300-Core-dkh.4'. ].
! !

!ConfigurationOfGrease methodsFor: 'versions' stamp: 'dkh 11/17/2011 14:11'!
version1064: spec
	<version: '1.0.6.4' imports: #('1.0.6.1-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'release'.
		spec description: '1.0.6.4 (dkh.174):
- open 1.0.6.4 for development
- support for GemStone/S 2.4.5 release'.
		spec author: 'dkh'.
		spec timestamp: '11/17/2011 14:11'.
		spec 
			package: 'Grease-Core' with: 'Grease-Core-lr.66';
			package: 'Grease-Tests-Core' with: 'Grease-Tests-Core-lr.79'. ].

	spec for: #'squeakCommon' do: [
		spec 
			package: 'Grease-Pharo-Core' with: 'Grease-Pharo-Core-lr.44';
			package: 'Grease-Tests-Pharo-Core' with: 'Grease-Tests-Pharo-Core-lr.13'. ].

	spec for: #'pharo' do: [
		spec project: 'Refactoring-Core' with: #'stable'.
		spec 
			package: 'Grease-Slime' with: 'Grease-Slime-lr.14';
			package: 'Grease-Tests-Slime' with: 'Grease-Tests-Slime-lr.10'. ].

	spec for: #'GreaseForPharo1.0' do: [
		spec package: 'Grease-Pharo10-Core' with: 'Grease-Pharo10-Core-dkh.4'. ].

	spec for: #'pharo1.1.x' do: [
		spec 
			package: 'Grease-Slime' with: 'Grease-Slime-lr.13';
			package: 'Grease-Tests-Slime' with: 'Grease-Tests-Slime-lr.9'. ].
	
	spec for: #'pharo1.0.x' do: [
		spec 
			package: 'Grease-Slime' with: 'Grease-Slime-lr.13';
			package: 'Grease-Tests-Slime' with: 'Grease-Tests-Slime-lr.9'. ].

	spec for: #'gemstone' do: [
		spec 
			project: 'GsCore' with: '0.245';
			project: 'SMTPMail' with: '0.239.1';
			project: 'UTF8' with: '0.239.1';
			project: 'System-Digital-Signatures' with: '0.239.1'.
		spec 
			package: 'Grease-GemStone-Core' with: [
				spec 
					file: 'Grease-GemStone-Core-dkh.47';
					postLoadDoIt: #'initializeTransactionMutex1051'. ];
			package: 'Grease-Tests-GemStone-Core' with: 'Grease-Tests-GemStone-Core-dkh.14'. ].

	spec for: #'gs2.x' do: [
		spec package: 'Grease-GemStone200-Core' with: 'Grease-GemStone200-Core-dkh.2'. ].

	spec for: #'gs2.3.x' do: [
		spec package: 'Grease-GemStone230-Core' with: 'Grease-GemStone230-Core-dkh.4'. ].

	spec for: #'gs2.4.x' do: [
		spec package: 'Grease-GemStone240-Core' with: 'Grease-GemStone240-Core-dkh.3'. ].

	spec for: #'gs3.x' do: [
		spec package: 'Grease-GemStone300-Core' with: 'Grease-GemStone300-Core-dkh.4'. ].
! !

!ConfigurationOfGrease methodsFor: 'versions' stamp: 'dkh 12/02/2011 14:45'!
version1065: spec
	<version: '1.0.6.5' imports: #('1.0.6.1-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: 'open 1.0.6.5 for development
1.0.6.5 (dkh.177) [GemStone only];
- reimplement SendMail>>connectTo:on: to be portable between GemStone/S 2.x and 3.x'.
		spec author: 'dkh'.
		spec timestamp: '12/2/2011 14:16'.
		spec 
			package: 'Grease-Core' with: 'Grease-Core-lr.66';
			package: 'Grease-Tests-Core' with: 'Grease-Tests-Core-lr.79'. ].

	spec for: #'squeakCommon' do: [
		spec 
			package: 'Grease-Pharo-Core' with: 'Grease-Pharo-Core-lr.44';
			package: 'Grease-Tests-Pharo-Core' with: 'Grease-Tests-Pharo-Core-lr.13'. ].

	spec for: #'pharo' do: [
		spec project: 'Refactoring-Core' with: #'stable'.
		spec 
			package: 'Grease-Slime' with: 'Grease-Slime-lr.14';
			package: 'Grease-Tests-Slime' with: 'Grease-Tests-Slime-lr.10'. ].

	spec for: #'GreaseForPharo1.0' do: [
		spec package: 'Grease-Pharo10-Core' with: 'Grease-Pharo10-Core-dkh.4'. ].

	spec for: #'pharo1.1.x' do: [
		spec 
			package: 'Grease-Slime' with: 'Grease-Slime-lr.13';
			package: 'Grease-Tests-Slime' with: 'Grease-Tests-Slime-lr.9'. ].
	
	spec for: #'pharo1.0.x' do: [
		spec 
			package: 'Grease-Slime' with: 'Grease-Slime-lr.13';
			package: 'Grease-Tests-Slime' with: 'Grease-Tests-Slime-lr.9'. ].

	spec for: #'gemstone' do: [
		spec 
			project: 'GsCore' with: '0.245.2';
			project: 'SMTPMail' with: '0.240.1';
			project: 'UTF8' with: '0.240.1';
			project: 'System-Digital-Signatures' with: '0.240.1'.
		spec 
			package: 'Grease-GemStone-Core' with: [
				spec 
					file: 'Grease-GemStone-Core-dkh.47';
					postLoadDoIt: #'initializeTransactionMutex1051'. ];
			package: 'Grease-Tests-GemStone-Core' with: 'Grease-Tests-GemStone-Core-dkh.14'. ].

	spec for: #'gs2.x' do: [
		spec package: 'Grease-GemStone200-Core' with: 'Grease-GemStone200-Core-dkh.2'. ].

	spec for: #'gs2.3.x' do: [
		spec package: 'Grease-GemStone230-Core' with: 'Grease-GemStone230-Core-dkh.4'. ].

	spec for: #'gs2.4.x' do: [
		spec package: 'Grease-GemStone240-Core' with: 'Grease-GemStone240-Core-dkh.3'. ].

	spec for: #'gs3.x' do: [
		spec package: 'Grease-GemStone300-Core' with: 'Grease-GemStone300-Core-dkh.4'. ].
! !

!ConfigurationOfGrease methodsFor: 'versions' stamp: 'dkh 9/11/2011 11:34'!
version106: spec
	<version: '1.0.6' imports: #('1.0.4-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'release'.
		spec description: '1.0.6 (dkh.153):
- open 1.0.6 for development
- update to latest packages (http://code.google.com/p/seaside/wiki/Seaside306Changelog)
- update GRPlatform version to 1.0.6
1.0.6 (dkh.154) [GEMSTONE]:
- merge Grease-GemStone-Core-NickAger.43
1.0.6 (dkh.155) [GEMSTONE]:
- fix Issue 290: transactionMutex is always nil
  http://code.google.com/p/glassdb/issues/detail?id=290
- fix Issue 287: Pick up GsMisc v.0239.1
  http://code.google.com/p/glassdb/issues/detail?id=287'.
		spec author: 'dkh'.
		spec timestamp: '09/02/2011 17:03:50'.
		spec 
			package: 'Grease-Core' with: 'Grease-Core-dkh.65';
			package: 'Grease-Tests-Core' with: 'Grease-Tests-Core-pmm.78'. ].

	spec for: #'squeakCommon' do: [
		spec 
			package: 'Grease-Pharo-Core' with: 'Grease-Pharo-Core-pmm.43';
			package: 'Grease-Tests-Pharo-Core' with: 'Grease-Tests-Pharo-Core-lr.13'. ].

	spec for: #'pharo' do: [
		spec project: 'Refactoring-Core' with: #'stable'.
		spec 
			package: 'Grease-Slime' with: 'Grease-Slime-lr.13';
			package: 'Grease-Tests-Slime' with: 'Grease-Tests-Slime-lr.9'. ].

	spec for: #'GreaseForPharo1.0' do: [
		spec package: 'Grease-Pharo10-Core' with: 'Grease-Pharo10-Core-dkh.4'. ].

	spec for: #'gemstone' do: [
		spec 
			project: 'GsCore' with: '0.245';
			project: 'SMTPMail' with: '0.239.1';
			project: 'UTF8' with: '0.239.1';
			project: 'System-Digital-Signatures' with: '0.239.1'.
		spec 
			package: 'Grease-GemStone-Core' with: [
				spec 
					file: 'Grease-GemStone-Core-dkh.44';
					postLoadDoIt: #'initializeTransactionMutex1051'. ];
			package: 'Grease-Tests-GemStone-Core' with: 'Grease-Tests-GemStone-Core-dkh.14'. ].

	spec for: #'gs2.3.x' do: [
		spec package: 'Grease-GemStone230-Core' with: 'Grease-GemStone230-Core-dkh.2'. ].

	spec for: #'gs2.4.x' do: [
		spec package: 'Grease-GemStone240-Core' with: 'Grease-GemStone240-Core-dkh.3'. ].

	spec for: #'gs3.x' do: [
		spec package: 'Grease-GemStone300-Core' with: 'Grease-GemStone300-Core-DaleHenrichs.2'. ].
! !

!ConfigurationOfGrease methodsFor: 'versions' stamp: 'dkh 4/27/2012 10:13'!
version1071: spec
	<version: '1.0.7.1' imports: #('1.0.7.1-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '- Port Grease to Pharo2.0.
- BlockContext class no longer exists in Pharo2.0, so the BlockContext extension methods only needed for Pharo1.3 and earlier
- Slime not ported to Pharo2.0, yet, so exclude'.
		spec author: 'dkh'.
		spec timestamp: '4/25/2012 12:08'.
		spec 
			package: 'Grease-Core' with: 'Grease-Core-NickAger.70';
			package: 'Grease-Tests-Core' with: 'Grease-Tests-Core-pmm.80'. ].

	spec for: #'squeakCommon' do: [
		spec 
			package: 'Grease-Pharo-Core' with: 'Grease-Pharo-Core-dkh.50';
			package: 'Grease-Tests-Pharo-Core' with: 'Grease-Tests-Pharo-Core-lr.13'. ].

	spec for: #'pharo1.x' do: [
		spec project: 'Refactoring-Core' with: #'stable'.
		spec 
			package: 'Grease-Slime' with: 'Grease-Slime-lr.14';
			package: 'Grease-Tests-Slime' with: 'Grease-Tests-Slime-lr.10';
			package: 'Grease-Pharo13-Core' with: 'Grease-Pharo13-Core-dkh.1'. ].

	spec for: #'squeak' do: [
		spec 
			package: 'Grease-Pharo13-Core' with: 'Grease-Pharo13-Core-dkh.1'. ].
	
	spec for: #'pharo1.1.x' do: [
		spec 
			package: 'Grease-Slime' with: 'Grease-Slime-lr.13';
			package: 'Grease-Tests-Slime' with: 'Grease-Tests-Slime-lr.9'. ].

	spec for: #'pharo1.0.x' do: [
		spec 
			package: 'Grease-Slime' with: 'Grease-Slime-lr.13';
			package: 'Grease-Tests-Slime' with: 'Grease-Tests-Slime-lr.9'. ].

	spec for: #'GreaseForPharo1.0' do: [
		spec package: 'Grease-Pharo10-Core' with: 'Grease-Pharo10-Core-dkh.4'. ].

	spec for: #'gemstone' do: [
		spec 
			project: 'GsCore' with: '0.245.2';
			project: 'SMTPMail' with: '0.240.1';
			project: 'UTF8' with: '0.240.1';
			project: 'System-Digital-Signatures' with: '0.240.1'.
		spec 
			package: 'Grease-GemStone-Core' with: [
				spec 
					file: 'Grease-GemStone-Core-dkh.47';
					postLoadDoIt: #'initializeTransactionMutex1051'. ];
			package: 'Grease-Tests-GemStone-Core' with: 'Grease-Tests-GemStone-Core-dkh.14'. ].

	spec for: #'gs2.x' do: [
		spec package: 'Grease-GemStone200-Core' with: 'Grease-GemStone200-Core-dkh.2'. ].

	spec for: #'gs2.3.x' do: [
		spec package: 'Grease-GemStone230-Core' with: 'Grease-GemStone230-Core-dkh.4'. ].

	spec for: #'gs2.4.x' do: [
		spec package: 'Grease-GemStone240-Core' with: 'Grease-GemStone240-Core-dkh.3'. ].

	spec for: #'gs3.x' do: [
		spec package: 'Grease-GemStone300-Core' with: 'Grease-GemStone300-Core-dkh.4'. ].
! !

!ConfigurationOfGrease methodsFor: 'versions' stamp: 'dkh 4/25/2012 10:31'!
version107: spec
	<version: '1.0.7' imports: #('1.0.6.1-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'release'.
		spec description: ''.
		spec author: 'dkh'.
		spec timestamp: '3/28/2012 16:39'.
		spec 
			package: 'Grease-Core' with: 'Grease-Core-NickAger.70';
			package: 'Grease-Tests-Core' with: 'Grease-Tests-Core-pmm.80'. ].

	spec for: #'squeakCommon' do: [
		spec 
			package: 'Grease-Pharo-Core' with: 'Grease-Pharo-Core-NickAger.49';
			package: 'Grease-Tests-Pharo-Core' with: 'Grease-Tests-Pharo-Core-lr.13'. ].

	spec for: #'pharo' do: [
		spec project: 'Refactoring-Core' with: #'stable'.
		spec 
			package: 'Grease-Slime' with: 'Grease-Slime-lr.14';
			package: 'Grease-Tests-Slime' with: 'Grease-Tests-Slime-lr.10'. ].

	spec for: #'GreaseForPharo1.0' do: [
		spec package: 'Grease-Pharo10-Core' with: 'Grease-Pharo10-Core-dkh.4'. ].

	spec for: #'pharo1.1.x' do: [
		spec 
			package: 'Grease-Slime' with: 'Grease-Slime-lr.13';
			package: 'Grease-Tests-Slime' with: 'Grease-Tests-Slime-lr.9'. ].
	
	spec for: #'pharo1.0.x' do: [
		spec 
			package: 'Grease-Slime' with: 'Grease-Slime-lr.13';
			package: 'Grease-Tests-Slime' with: 'Grease-Tests-Slime-lr.9'. ].

	spec for: #'gemstone' do: [
		spec 
			project: 'GsCore' with: '0.245.2';
			project: 'SMTPMail' with: '0.240.1';
			project: 'UTF8' with: '0.240.1';
			project: 'System-Digital-Signatures' with: '0.240.1'.
		spec 
			package: 'Grease-GemStone-Core' with: [
				spec 
					file: 'Grease-GemStone-Core-dkh.47';
					postLoadDoIt: #'initializeTransactionMutex1051'. ];
			package: 'Grease-Tests-GemStone-Core' with: 'Grease-Tests-GemStone-Core-dkh.14'. ].

	spec for: #'gs2.x' do: [
		spec package: 'Grease-GemStone200-Core' with: 'Grease-GemStone200-Core-dkh.2'. ].

	spec for: #'gs2.3.x' do: [
		spec package: 'Grease-GemStone230-Core' with: 'Grease-GemStone230-Core-dkh.4'. ].

	spec for: #'gs2.4.x' do: [
		spec package: 'Grease-GemStone240-Core' with: 'Grease-GemStone240-Core-dkh.3'. ].

	spec for: #'gs3.x' do: [
		spec package: 'Grease-GemStone300-Core' with: 'Grease-GemStone300-Core-dkh.4'. ].
! !

!ConfigurationOfGrease methodsFor: 'versions' stamp: 'DaleHenrichs 10/11/2010 14:46'!
version10: spec
	<version: '1.0' imports: #('1.0-baseline' )>

	spec for: #common do: [
		spec blessing: #release.
		spec description: '- 1.0 final'.
		spec author: 'DaleHenrichs'.
		spec timestamp: '10/11/2010 14:46'.
		spec 
			package: 'Grease-Core' with: 'Grease-Core-lr.48';
			package: 'Grease-Tests-Core' with: 'Grease-Tests-Core-pmm.60'.].
	spec for: #squeakCommon do: [
		spec 
			package: 'Grease-Pharo-Core' with: 'Grease-Pharo-Core-lr.29';
			package: 'Grease-Tests-Pharo-Core' with: 'Grease-Tests-Pharo-Core-pmm.8'.].
	spec for: #pharo do: [
		spec project: 'Refactoring-Core' with: '1.4'.
		spec 
			package: 'Grease-Slime' with: 'Grease-Slime-jok.5';
			package: 'Grease-Tests-Slime' with: 'Grease-Tests-Slime-jok.5'.].
	spec for: #'GreaseForPharo1.0' do: [
		spec package: 'Grease-Pharo10-Core' with: 'Grease-Pharo10-Core-pmm.2'].
	spec for: #gemstone do: [
		spec 
			project: 'GsCore' with: '0.241';
			project: 'SMTPMail' with: '0.237';
			project: 'UTF8' with: '0.237';
			project: 'System-Digital-Signatures' with: '0.237'.
		spec 
			package: 'Grease-GemStone-Core' with: [
				spec 
					file: 'Grease-GemStone-Core-DaleHenrichs.26';
					postLoadDoIt: #initializeNewRandomCaches10alpha3. ];
			package: 'Grease-Tests-GemStone-Core' with: 'Grease-Tests-GemStone-Core-DaleHenrichs.8'.].
	spec for: #'gs2.3.x' do: [
		spec package: 'Grease-GemStone230-Core' with: 'Grease-GemStone230-Core-dkh.2'.].
	spec for: #'gs2.4.x' do: [
		spec package: 'Grease-GemStone240-Core' with: 'Grease-GemStone240-Core-DaleHenrichs.2'.].
	spec for: #'gs3.x' do: [
		spec package: 'Grease-GemStone300-Core' with: 'Grease-GemStone300-Core-DaleHenrichs.2'.].! !

!ConfigurationOfGrease methodsFor: 'versions' stamp: 'dkh 11/13/2009 10:41'!
version10alpha1: spec
	<version: '1.0-alpha1' imports: #('1.0-alpha1-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'alpha'.
		spec author: 'dkh'.
		spec timestamp: '11/12/2009 09:41'.
		spec 
			package: 'Grease-Core' with: 'Grease-Core-obi.3';
			package: 'Grease-Tests-Core' with: 'Grease-Tests-Core-jf.1'.].
	spec for: #'squeakCommon' do: [
		spec 
			package: 'Grease-Pharo-Core' with: 'Grease-Pharo-Core-jf.1';
			package: 'Grease-Tests-Pharo-Core' with: 'Grease-Tests-Pharo-Core-jf.1'.].
	spec for: #'gemstone' do: [
		spec
			project: 'UTF8' with: '0.233';
			project: 'System-Digital-Signatures' with: '0.233'.
		spec 
			package: 'Grease-GemStone-Core' with: 'Grease-GemStone-Core-dkh.5';
			package: 'Grease-Tests-GemStone-Core' with: 'Grease-Tests-GemStone-Core-dkh.3'.].! !

!ConfigurationOfGrease methodsFor: 'versions' stamp: 'dkh 12/8/2009 16:07'!
version10alpha2: spec
	<version: '1.0-alpha2' imports: #('1.0-alpha2-baseline' )>

	spec for: #common do: [
		spec blessing: #alpha.
		spec description: '- in GemStone the block arg for #on:do: must always have an argument
- fix Issue 480: http://code.google.com/p/seaside/issues/detail?id=480 (GemStone/Pharo)
- fix Issue 488: http://code.google.com/p/seaside/issues/detail?id=488
- fix Issue 499: http://code.google.com/p/seaside/issues/detail?id=499 (GemStone/Pharo)
- support for loading Grease into a 2.3 GemStone/S repository
- support ''UTF-8'' has a codec name as well
- pick up latest repository changes as of 11/17/2009 15:09"
'.
		spec author: 'dkh'.
		spec timestamp: '11/23/2009 16:09'.
		spec 
			package: 'Grease-Core' with: 'Grease-Core-dkh.8';
			package: 'Grease-Tests-Core' with: 'Grease-Tests-Core-pmm.5'.].
	spec for: #squeakCommon do: [
		spec 
			package: 'Grease-Pharo-Core' with: 'Grease-Pharo-Core-dkh.3';
			package: 'Grease-Tests-Pharo-Core' with: 'Grease-Tests-Pharo-Core-dkh.2'.].
	spec for: #gemstone do: [
		spec 
			project: 'SMTPMail' with: '0.233';
			project: 'UTF8' with: '0.233';
			project: 'System-Digital-Signatures' with: '0.233'.
		spec 
			package: 'Grease-GemStone-Core' with: 'Grease-GemStone-Core-dkh.9';
			package: 'Grease-Tests-GemStone-Core' with: 'Grease-Tests-GemStone-Core-dkh.5'.].
	spec for: #'gs2.3.x' do: [
		spec package: 'Grease-GemStone230-Core' with: 'Grease-GemStone230-Core-dkh.2'.].! !

!ConfigurationOfGrease methodsFor: 'versions' stamp: 'DaleHenrichs 1/22/2010 10:55'!
version10alpha3: spec
	<version: '1.0-alpha3' imports: #('1.0-alpha2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'alpha'.
		spec description: '- pick up latest developer package versions (12/8/2009 16:14)"
'.
		spec author: 'dkh'.
		spec timestamp: '12/23/09 16:52:29'.
		spec 
			package: 'Grease-Core' with: 'Grease-Core-dkh.8';
			package: 'Grease-Tests-Core' with: 'Grease-Tests-Core-jf.7'.].
	spec for: #'squeakCommon' do: [
		spec 
			package: 'Grease-Pharo-Core' with: 'Grease-Pharo-Core-dkh.4';
			package: 'Grease-Tests-Pharo-Core' with: 'Grease-Tests-Pharo-Core-dkh.2'.].
	spec for: #'gemstone' do: [
		spec 
			project: 'SMTPMail' with: '0.233';
			project: 'UTF8' with: '0.233';
			project: 'System-Digital-Signatures' with: '0.233'.
		spec 
			package: 'Grease-GemStone-Core' with: [
				spec 
					file: 'Grease-GemStone-Core-dkh.12';
					postLoadDoIt: #'initializeNewRandomCaches10alpha3'. ];
			package: 'Grease-Tests-GemStone-Core' with: 'Grease-Tests-GemStone-Core-dkh.5'.].
	spec for: #'gs2.3.x' do: [
		spec package: 'Grease-GemStone230-Core' with: 'Grease-GemStone230-Core-dkh.2'.].! !

!ConfigurationOfGrease methodsFor: 'versions' stamp: 'DaleHenrichs 1/22/2010 16:02'!
version10alpha4: spec
	<version: '1.0-alpha4' imports: #('1.0-alpha2-baseline' )>

	spec for: #common do: [
		spec blessing: #alpha.
		spec description: '- pick up latest developer package versions (1/22/2010 12:06)"
'.
		spec author: 'DaleHenrichs'.
		spec timestamp: '1/22/2010 12:08'.
		spec 
			package: 'Grease-Core' with: 'Grease-Core-jf.14';
			package: 'Grease-Tests-Core' with: 'Grease-Tests-Core-jok.17'.].
	spec for: #squeakCommon do: [
		spec 
			package: 'Grease-Pharo-Core' with: 'Grease-Pharo-Core-jf.7';
			package: 'Grease-Tests-Pharo-Core' with: 'Grease-Tests-Pharo-Core-jf.5'.].
	spec for: #gemstone do: [
		spec blessing: #broken.
		spec description: 'NOT PORTED TO GEMSTONE'.
		spec 
			project: 'SMTPMail' with: '0.233';
			project: 'UTF8' with: '0.233';
			project: 'System-Digital-Signatures' with: '0.233'.
		spec 
			package: 'Grease-GemStone-Core' with: [
				spec 
					file: 'Grease-GemStone-Core-dkh.12';
					postLoadDoIt: #initializeNewRandomCaches10alpha3. ];
			package: 'Grease-Tests-GemStone-Core' with: 'Grease-Tests-GemStone-Core-dkh.5'.].
	spec for: #'gs2.3.x' do: [
		spec package: 'Grease-GemStone230-Core' with: 'Grease-GemStone230-Core-dkh.2'.].! !

!ConfigurationOfGrease methodsFor: 'versions' stamp: 'dkh 1/27/2010 15:38'!
version10alpha501: spec
	<version: '1.0-alpha5.1' imports: #('1.0-alpha5-baseline' )>

	spec for: #common do: [
		spec blessing: #alpha.
		spec description: '- pick up latest developer package versions (1/22/2010 12:06)"
'.
		spec author: 'dkh'.
		spec timestamp: '1/27/2010 15:01'.
		spec 
			package: 'Grease-Core' with: 'Grease-Core-jok.15';
			package: 'Grease-Tests-Core' with: 'Grease-Tests-Core-jok.22'.].
	spec for: #squeakCommon do: [
		spec 
			package: 'Grease-Pharo-Core' with: 'Grease-Pharo-Core-jf.8';
			package: 'Grease-Tests-Pharo-Core' with: 'Grease-Tests-Pharo-Core-jf.5'.].
	spec for: #pharo do: [
		spec project: 'Refactoring-Core' with: '1.1'.
		spec
			package: 'Grease-Slime' with: 'Grease-Slime-jok.2';
			package: 'Grease-Tests-Slime' with: 'Grease-Tests-Slime-jok.1'. ].
	spec for: #gemstone do: [
		spec blessing: #broken.
		spec description: 'NOT PORTED TO GEMSTONE'.
		spec 
			project: 'SMTPMail' with: '0.233';
			project: 'UTF8' with: '0.233';
			project: 'System-Digital-Signatures' with: '0.233'.
		spec 
			package: 'Grease-GemStone-Core' with: [
				spec 
					file: 'Grease-GemStone-Core-dkh.12';
					postLoadDoIt: #initializeNewRandomCaches10alpha3. ];
			package: 'Grease-Tests-GemStone-Core' with: 'Grease-Tests-GemStone-Core-dkh.5'.].
	spec for: #'gs2.3.x' do: [
		spec package: 'Grease-GemStone230-Core' with: 'Grease-GemStone230-Core-dkh.2'.].! !

!ConfigurationOfGrease methodsFor: 'versions' stamp: 'DaleHenrichs 3/1/2010 14:57'!
version10alpha6: spec
	<version: '1.0-alpha6' imports: #('1.0-alpha5-baseline' )>

	spec for: #common do: [
		spec blessing: #alpha.
		spec description: '- pick up latest developer package versions (3/1/2010 12:39)
'.
		spec author: 'DaleHenrichs'.
		spec timestamp: '3/1/2010 13:16'.
		spec 
			package: 'Grease-Core' with: 'Grease-Core-obi.30';
			package: 'Grease-Tests-Core' with: 'Grease-Tests-Core-pmm.39'.].
	spec for: #squeakCommon do: [
		spec 
			package: 'Grease-Pharo-Core' with: 'Grease-Pharo-Core-pmm.13';
			package: 'Grease-Tests-Pharo-Core' with: 'Grease-Tests-Pharo-Core-lr.6'.].
	spec for: #pharo do: [
		spec project: 'Refactoring-Core' with: '1.1'.
		spec 
			package: 'Grease-Slime' with: 'Grease-Slime-lr.3';
			package: 'Grease-Tests-Slime' with: 'Grease-Tests-Slime-lr.2'.].
	spec for: #gemstone do: [
		spec blessing: #broken.
		spec description: 'NOT PORTED TO GEMSTONE'.
		spec 
			project: 'SMTPMail' with: '0.233';
			project: 'UTF8' with: '0.233';
			project: 'System-Digital-Signatures' with: '0.233'.
		spec 
			package: 'Grease-GemStone-Core' with: [
				spec 
					file: 'Grease-GemStone-Core-dkh.12';
					postLoadDoIt: #initializeNewRandomCaches10alpha3. ];
			package: 'Grease-Tests-GemStone-Core' with: 'Grease-Tests-GemStone-Core-dkh.5'.].
	spec for: #'gs2.3.x' do: [
		spec package: 'Grease-GemStone230-Core' with: 'Grease-GemStone230-Core-dkh.2'.].! !

!ConfigurationOfGrease methodsFor: 'versions' stamp: 'DaleHenrichs 3/29/2010 12:41'!
version10alpha7: spec
	<version: '1.0-alpha7' imports: #('1.0-alpha7-baseline' )>

	spec for: #common do: [
		spec blessing: #alpha.
		spec description: '- pick up latest developer package versions (3/29/2010 11:09)
'.
		spec author: 'DaleHenrichs'.
		spec timestamp: '3/29/2010 11:34'.
		spec 
			package: 'Grease-Core' with: 'Grease-Core-jok.31';
			package: 'Grease-Tests-Core' with: 'Grease-Tests-Core-jok.43'.].
	spec for: #squeakCommon do: [
		spec 
			package: 'Grease-Pharo-Core' with: 'Grease-Pharo-Core-jok.14';
			package: 'Grease-Tests-Pharo-Core' with: 'Grease-Tests-Pharo-Core-lr.6'.].
	spec for: #pharo do: [
		spec project: 'Refactoring-Core' with: '1.2'.
		spec 
			package: 'Grease-Slime' with: 'Grease-Slime-jok.4';
			package: 'Grease-Tests-Slime' with: 'Grease-Tests-Slime-jok.3'.].
	spec for: #gemstone do: [
		spec blessing: #broken.
		spec description: 'NOT PORTED TO GEMSTONE'.
		spec 
			project: 'SMTPMail' with: '0.233';
			project: 'UTF8' with: '0.233';
			project: 'System-Digital-Signatures' with: '0.233'.
		spec 
			package: 'Grease-GemStone-Core' with: [
				spec 
					file: 'Grease-GemStone-Core-dkh.12';
					postLoadDoIt: #initializeNewRandomCaches10alpha3. ];
			package: 'Grease-Tests-GemStone-Core' with: 'Grease-Tests-GemStone-Core-dkh.5'.].
	spec for: #'gs2.3.x' do: [
		spec package: 'Grease-GemStone230-Core' with: 'Grease-GemStone230-Core-dkh.2'.].! !

!ConfigurationOfGrease methodsFor: 'versions' stamp: 'DaleHenrichs 4/9/2010 15:52'!
version10alpha8: spec
	<version: '1.0-alpha8' imports: #('1.0-alpha7-baseline' )>

	spec for: #common do: [
		spec blessing: #development.
		spec description: '- pick up latest developer package versions (4/9/2010 15:51)
'.
		spec author: 'DaleHenrichs'.
		spec timestamp: '4/9/2010 15:52'.
		spec 
			package: 'Grease-Core' with: 'Grease-Core-jok.31';
			package: 'Grease-Tests-Core' with: 'Grease-Tests-Core-jok.45'.].
	spec for: #squeakCommon do: [
		spec 
			package: 'Grease-Pharo-Core' with: 'Grease-Pharo-Core-lr.15';
			package: 'Grease-Tests-Pharo-Core' with: 'Grease-Tests-Pharo-Core-lr.6'.].
	spec for: #pharo do: [
		spec project: 'Refactoring-Core' with: '1.2'.
		spec 
			package: 'Grease-Slime' with: 'Grease-Slime-jok.4';
			package: 'Grease-Tests-Slime' with: 'Grease-Tests-Slime-lr.4'.].
	spec for: #gemstone do: [
		spec blessing: #broken.
		spec description: 'NOT PORTED TO GEMSTONE'.
		spec 
			project: 'SMTPMail' with: '0.233';
			project: 'UTF8' with: '0.233';
			project: 'System-Digital-Signatures' with: '0.233'.
		spec 
			package: 'Grease-GemStone-Core' with: [
				spec 
					file: 'Grease-GemStone-Core-dkh.12';
					postLoadDoIt: #initializeNewRandomCaches10alpha3. ];
			package: 'Grease-Tests-GemStone-Core' with: 'Grease-Tests-GemStone-Core-dkh.5'.].
	spec for: #'gs2.3.x' do: [
		spec package: 'Grease-GemStone230-Core' with: 'Grease-GemStone230-Core-dkh.2'.].! !

!ConfigurationOfGrease methodsFor: 'versions' stamp: 'dkh 5/14/2010 17:09'!
version10alpha91: spec
	<version: '1.0-alpha9.1' imports: #('1.0-alpha7-baseline' )>

	spec for: #common do: [
		spec blessing: #alpha.
		spec description: '- pick up latest developer package versions Pharo1.1 compat (5/14/2010 13:29)
- pick up latest Refactoring-Core
'.
		spec author: 'DaleHenrichs'.
		spec timestamp: '5/14/2010 13:47'.
		spec 
			package: 'Grease-Core' with: 'Grease-Core-lr.37';
			package: 'Grease-Tests-Core' with: 'Grease-Tests-Core-lr.50'.].
	spec for: #squeakCommon do: [
		spec 
			package: 'Grease-Pharo-Core' with: 'Grease-Pharo-Core-jok.18';
			package: 'Grease-Tests-Pharo-Core' with: 'Grease-Tests-Pharo-Core-jok.7'.].
	spec for: #pharo do: [
		spec project: 'Refactoring-Core' with: '1.3'.
		spec 
			package: 'Grease-Slime' with: 'Grease-Slime-jok.5';
			package: 'Grease-Tests-Slime' with: 'Grease-Tests-Slime-jok.5'.].
	spec for: #gemstone do: [
		spec blessing: #broken.
		spec description: 'NOT PORTED TO GEMSTONE'.
		spec 
			project: 'SMTPMail' with: '0.233';
			project: 'UTF8' with: '0.233';
			project: 'System-Digital-Signatures' with: '0.233'.
		spec 
			package: 'Grease-GemStone-Core' with: [
				spec 
					file: 'Grease-GemStone-Core-dkh.12';
					postLoadDoIt: #initializeNewRandomCaches10alpha3. ];
			package: 'Grease-Tests-GemStone-Core' with: 'Grease-Tests-GemStone-Core-dkh.5'.].
	spec for: #'gs2.3.x' do: [
		spec package: 'Grease-GemStone230-Core' with: 'Grease-GemStone230-Core-dkh.2'.].! !

!ConfigurationOfGrease methodsFor: 'versions' stamp: 'DaleHenrichs 6/1/2010 14:33'!
version10alpha92: spec
	<version: '1.0-alpha9.2' imports: #('1.0-alpha7-baseline' )>

	spec for: #common do: [
		spec blessing: #alpha.
		spec description: '- pick up latest mcz files(6/1/2010 10:21)
'.
		spec author: 'DaleHenrichs'.
		spec timestamp: '6/1/2010 10:21'.
		spec 
			package: 'Grease-Core' with: 'Grease-Core-pmm.42';
			package: 'Grease-Tests-Core' with: 'Grease-Tests-Core-pmm.56'.].
	spec for: #squeakCommon do: [
		spec 
			package: 'Grease-Pharo-Core' with: 'Grease-Pharo-Core-pmm.23';
			package: 'Grease-Tests-Pharo-Core' with: 'Grease-Tests-Pharo-Core-jok.7'.].
	spec for: #pharo do: [
		spec project: 'Refactoring-Core' with: '1.3'.
		spec 
			package: 'Grease-Slime' with: 'Grease-Slime-jok.5';
			package: 'Grease-Tests-Slime' with: 'Grease-Tests-Slime-jok.5'.].
	spec for: #gemstone do: [
		spec blessing: #broken.
		spec description: 'NOT PORTED TO GEMSTONE'.
		spec 
			project: 'SMTPMail' with: '0.233';
			project: 'UTF8' with: '0.233';
			project: 'System-Digital-Signatures' with: '0.233'.
		spec 
			package: 'Grease-GemStone-Core' with: [
				spec 
					file: 'Grease-GemStone-Core-dkh.12';
					postLoadDoIt: #initializeNewRandomCaches10alpha3. ];
			package: 'Grease-Tests-GemStone-Core' with: 'Grease-Tests-GemStone-Core-dkh.5'.].
	spec for: #'gs2.3.x' do: [
		spec package: 'Grease-GemStone230-Core' with: 'Grease-GemStone230-Core-dkh.2'.].! !

!ConfigurationOfGrease methodsFor: 'versions' stamp: 'DaleHenrichs 7/13/2010 10:24'!
version10alpha93: spec
	<version: '1.0-alpha9.3' imports: #('1.0-alpha9.3-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'release'.
		spec description: '- refactor groups:
On platforms without Slime
   ''Core''        = #(''Grease-Core'')
   ''Core Tests''  = #(''Grease-Tests-Core'')
   ''Slime''       = #(''Core'')
   ''Slime Tests'' = #(''Core Tests'')
   ''Tests''       = #(''Core Tests'' ''Slime Tests'')
   ''default''     = #(''Slime'')
On platforms with Slime
   ''Core''        = #(''Grease-Core'')
   ''Core Tests''  = #(''Grease-Tests-Core'')
   ''Slime''       = #(''Core'' ''Grease-Slime'')
   ''Slime Tests'' = #(''Core Tests'' ''Grease-Tests-Slime'')
   ''Tests''       = #(''Core Tests'' ''Slime Tests'')
   ''default''     = #(''Slime'')
- port to GemStone GLASS 1.0-beta.8
- adjust grease tests for GemStone Interval implementation; replace #= with #keysAndValuesDo:
'.
		spec author: 'DaleHenrichs'.
		spec timestamp: '6/4/2010 17:41'.
		spec 
			package: 'Grease-Core' with: 'Grease-Core-pmm.42';
			package: 'Grease-Tests-Core' with: 'Grease-Tests-Core-DaleHenrichs.58'.].
	spec for: #'squeakCommon' do: [
		spec 
			package: 'Grease-Pharo-Core' with: 'Grease-Pharo-Core-pmm.23';
			package: 'Grease-Tests-Pharo-Core' with: 'Grease-Tests-Pharo-Core-jok.7'.].
	spec for: #'pharo' do: [
		spec project: 'Refactoring-Core' with: '1.3'.
		spec 
			package: 'Grease-Slime' with: 'Grease-Slime-jok.5';
			package: 'Grease-Tests-Slime' with: 'Grease-Tests-Slime-jok.5'.].
	spec for: #'gemstone' do: [
		spec 
			project: 'GsCore' with: '0.241';
			project: 'SMTPMail' with: '0.236';
			project: 'UTF8' with: '0.236';
			project: 'System-Digital-Signatures' with: '0.236'.
		spec 
			package: 'Grease-GemStone-Core' with: [
				spec 
					file: 'Grease-GemStone-Core-DaleHenrichs.16';
					postLoadDoIt: #'initializeNewRandomCaches10alpha3'. ];
			package: 'Grease-Tests-GemStone-Core' with: 'Grease-Tests-GemStone-Core-DaleHenrichs.7'.].
	spec for: #'gs2.3.x' do: [
		spec package: 'Grease-GemStone230-Core' with: 'Grease-GemStone230-Core-dkh.2'.].! !

!ConfigurationOfGrease methodsFor: 'versions' stamp: 'DaleHenrichs 5/12/2010 17:56'!
version10alpha9: spec
	<version: '1.0-alpha9' imports: #('1.0-alpha7-baseline' )>

	spec for: #common do: [
		spec blessing: #alpha.
		spec description: '- pick up latest developer package versions (5/12/2010 16:34)
- 1.0-alpha8 skipped as it is still in development'.
		spec author: 'DaleHenrichs'.
		spec timestamp: '5/12/2010 17:15'.
		spec 
			package: 'Grease-Core' with: 'Grease-Core-DaleHenrichs.36';
			package: 'Grease-Tests-Core' with: 'Grease-Tests-Core-lr.49'.].
	spec for: #squeakCommon do: [
		spec 
			package: 'Grease-Pharo-Core' with: 'Grease-Pharo-Core-jok.18';
			package: 'Grease-Tests-Pharo-Core' with: 'Grease-Tests-Pharo-Core-jok.7'.].
	spec for: #pharo do: [
		spec project: 'Refactoring-Core' with: '1.2'.
		spec 
			package: 'Grease-Slime' with: 'Grease-Slime-jok.5';
			package: 'Grease-Tests-Slime' with: 'Grease-Tests-Slime-jok.5'.].
	spec for: #gemstone do: [
		spec blessing: #broken.
		spec description: 'NOT PORTED TO GEMSTONE'.
		spec 
			project: 'SMTPMail' with: '0.233';
			project: 'UTF8' with: '0.233';
			project: 'System-Digital-Signatures' with: '0.233'.
		spec 
			package: 'Grease-GemStone-Core' with: [
				spec 
					file: 'Grease-GemStone-Core-dkh.12';
					postLoadDoIt: #initializeNewRandomCaches10alpha3. ];
			package: 'Grease-Tests-GemStone-Core' with: 'Grease-Tests-GemStone-Core-dkh.5'.].
	spec for: #'gs2.3.x' do: [
		spec package: 'Grease-GemStone230-Core' with: 'Grease-GemStone230-Core-dkh.2'.].! !

!ConfigurationOfGrease methodsFor: 'versions' stamp: 'DaleHenrichs 08/27/2010 13:15'!
version10rc1: spec
	<version: '1.0-rc.1' imports: #('1.0-rc-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'release'.
		spec description: 'code updates as of 8/27/2010 10:49'.
		spec author: 'DaleHenrichs'.
		spec timestamp: '08/27/2010 12:05:55'.
		spec 
			package: 'Grease-Core' with: 'Grease-Core-jf.45';
			package: 'Grease-Tests-Core' with: 'Grease-Tests-Core-lr.59'.].
	spec for: #'squeakCommon' do: [
		spec 
			package: 'Grease-Pharo-Core' with: 'Grease-Pharo-Core-lr.27';
			package: 'Grease-Tests-Pharo-Core' with: 'Grease-Tests-Pharo-Core-pmm.8'.].
	spec for: #'pharo' do: [
		spec project: 'Refactoring-Core' with: '1.3'.
		spec 
			package: 'Grease-Slime' with: 'Grease-Slime-jok.5';
			package: 'Grease-Tests-Slime' with: 'Grease-Tests-Slime-jok.5'.].
	spec for: #'gemstone' do: [
		spec 
			project: 'GsCore' with: '0.241';
			project: 'SMTPMail' with: '0.237';
			project: 'UTF8' with: '0.237';
			project: 'System-Digital-Signatures' with: '0.237'.
		spec 
			package: 'Grease-GemStone-Core' with: [
				spec 
					file: 'Grease-GemStone-Core-DaleHenrichs.25';
					postLoadDoIt: #'initializeNewRandomCaches10alpha3'. ];
			package: 'Grease-Tests-GemStone-Core' with: 'Grease-Tests-GemStone-Core-DaleHenrichs.8'.].
	spec for: #'gs2.3.x' do: [
		spec package: 'Grease-GemStone230-Core' with: 'Grease-GemStone230-Core-dkh.2'.].
	spec for: #'gs2.4.x' do: [
		spec package: 'Grease-GemStone240-Core' with: 'Grease-GemStone240-Core-DaleHenrichs.2'.].
	spec for: #'gs3.x' do: [
		spec package: 'Grease-GemStone300-Core' with: 'Grease-GemStone300-Core-DaleHenrichs.2'.].! !

!ConfigurationOfGrease methodsFor: 'versions' stamp: 'DaleHenrichs 09/03/2010 09:49'!
version10rc2: spec
	<version: '1.0-rc.2' imports: #('1.0-rc-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'release'.
		spec description: 'GemStone bugfixes:
- fix Issue 165: http://code.google.com/p/glassdb/issues/detail?id=165 "Include GemStone version of Seaside-FileSystem in Seaside3.0"
'.
		spec author: 'DaleHenrichs'.
		spec timestamp: '09/02/2010 16:22:59'.
		spec 
			package: 'Grease-Core' with: 'Grease-Core-jf.45';
			package: 'Grease-Tests-Core' with: 'Grease-Tests-Core-lr.59'.].
	spec for: #'squeakCommon' do: [
		spec 
			package: 'Grease-Pharo-Core' with: 'Grease-Pharo-Core-lr.27';
			package: 'Grease-Tests-Pharo-Core' with: 'Grease-Tests-Pharo-Core-pmm.8'.].
	spec for: #'pharo' do: [
		spec project: 'Refactoring-Core' with: '1.3'.
		spec 
			package: 'Grease-Slime' with: 'Grease-Slime-jok.5';
			package: 'Grease-Tests-Slime' with: 'Grease-Tests-Slime-jok.5'.].
	spec for: #'gemstone' do: [
		spec 
			project: 'GsCore' with: '0.241';
			project: 'SMTPMail' with: '0.237';
			project: 'UTF8' with: '0.237';
			project: 'System-Digital-Signatures' with: '0.237'.
		spec 
			package: 'Grease-GemStone-Core' with: [
				spec 
					file: 'Grease-GemStone-Core-DaleHenrichs.26';
					postLoadDoIt: #'initializeNewRandomCaches10alpha3'. ];
			package: 'Grease-Tests-GemStone-Core' with: 'Grease-Tests-GemStone-Core-DaleHenrichs.8'.].
	spec for: #'gs2.3.x' do: [
		spec package: 'Grease-GemStone230-Core' with: 'Grease-GemStone230-Core-dkh.2'.].
	spec for: #'gs2.4.x' do: [
		spec package: 'Grease-GemStone240-Core' with: 'Grease-GemStone240-Core-DaleHenrichs.2'.].
	spec for: #'gs3.x' do: [
		spec package: 'Grease-GemStone300-Core' with: 'Grease-GemStone300-Core-DaleHenrichs.2'.].! !

!ConfigurationOfGrease methodsFor: 'versions' stamp: 'DaleHenrichs 07/27/2010 12:49'!
version10rc: spec
	<version: '1.0-rc' imports: #('1.0-rc-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'release'.
		spec description: '- Grease 1.0 release candidate
- port Grease to GemStone 3.0
'.
		spec author: 'DaleHenrichs'.
		spec timestamp: '07/27/10 12:49:44'.
		spec 
			package: 'Grease-Core' with: 'Grease-Core-pmm.42';
			package: 'Grease-Tests-Core' with: 'Grease-Tests-Core-DaleHenrichs.58'.].
	spec for: #'squeakCommon' do: [
		spec 
			package: 'Grease-Pharo-Core' with: 'Grease-Pharo-Core-DaleHenrichs.24';
			package: 'Grease-Tests-Pharo-Core' with: 'Grease-Tests-Pharo-Core-jok.7'.].
	spec for: #'pharo' do: [
		spec project: 'Refactoring-Core' with: '1.3'.
		spec 
			package: 'Grease-Slime' with: 'Grease-Slime-jok.5';
			package: 'Grease-Tests-Slime' with: 'Grease-Tests-Slime-jok.5'.].
	spec for: #'gemstone' do: [
		spec 
			project: 'GsCore' with: '0.241';
			project: 'SMTPMail' with: '0.237';
			project: 'UTF8' with: '0.237';
			project: 'System-Digital-Signatures' with: '0.237'.
		spec 
			package: 'Grease-GemStone-Core' with: [
				spec 
					file: 'Grease-GemStone-Core-DaleHenrichs.21';
					postLoadDoIt: #'initializeNewRandomCaches10alpha3'. ];
			package: 'Grease-Tests-GemStone-Core' with: 'Grease-Tests-GemStone-Core-DaleHenrichs.8'.].
	spec for: #'gs2.3.x' do: [
		spec package: 'Grease-GemStone230-Core' with: 'Grease-GemStone230-Core-dkh.2'.].
	spec for: #'gs2.4.x' do: [
		spec package: 'Grease-GemStone240-Core' with: 'Grease-GemStone240-Core-DaleHenrichs.2'.].
	spec for: #'gs3.x' do: [
		spec package: 'Grease-GemStone300-Core' with: 'Grease-GemStone300-Core-DaleHenrichs.2'.].! !

!ConfigurationOfGrease methodsFor: 'versions' stamp: 'pmm 8/27/2012 14:54'!
version110: spec
	<version: '1.1.0' imports: #('1.1.0-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'release'.
		spec description: ''.
		spec author: 'pmm'.
		spec timestamp: '08/05/2012 19:27'.
		spec 
			package: 'Grease-Core' with: 'Grease-Core-pmm.74';
			package: 'Grease-Tests-Core' with: 'Grease-Tests-Core-pmm.84'. ].

	spec for: #'squeakCommon' do: [
		spec 
			package: 'Grease-Pharo-Core' with: 'Grease-Pharo-Core-pmm.52';
			package: 'Grease-Tests-Pharo-Core' with: 'Grease-Tests-Pharo-Core-pmm.17'. ].

	spec for: #'pharo' do: [
		spec project: 'Refactoring-Core' with: #'stable'.
		spec 
			package: 'Grease-Slime' with: 'Grease-Slime-lr.17';
			package: 'Grease-Tests-Slime' with: 'Grease-Tests-Slime-pmm.11'.
		spec 
			package: 'Grease-Pharo20-Core' with: 'Grease-Pharo20-Core-pmm.10';
			package: 'Grease-Tests-Pharo20-Core' with: 'Grease-Tests-Pharo20-Core-pmm.3'. ].

	spec for: #'pharo1.x' do: [
		spec
			package: 'Grease-Pharo10-Core' with: 'Grease-Pharo10-Core-dkh.4';
			package: 'Grease-Pharo11-Core' with: 'Grease-Pharo11-Core-pmm.1'. ].

	spec for: #'gemstone' do: [
		spec 
			project: 'GsCore' with: '0.245.2';
			project: 'SMTPMail' with: '0.240.1';
			project: 'UTF8' with: '0.240.1';
			project: 'System-Digital-Signatures' with: '0.240.1'.
		spec 
			package: 'Grease-GemStone-Core' with: [
				spec 
					file: 'Grease-GemStone-Core-dkh.47';
					postLoadDoIt: #'initializeTransactionMutex1051'. ];
			package: 'Grease-Tests-GemStone-Core' with: 'Grease-Tests-GemStone-Core-dkh.14'. ].

	spec for: #'gs2.x' do: [
		spec package: 'Grease-GemStone200-Core' with: 'Grease-GemStone200-Core-dkh.2'. ].

	spec for: #'gs2.3.x' do: [
		spec package: 'Grease-GemStone230-Core' with: 'Grease-GemStone230-Core-dkh.4'. ].

	spec for: #'gs2.4.x' do: [
		spec package: 'Grease-GemStone240-Core' with: 'Grease-GemStone240-Core-dkh.3'. ].

	spec for: #'gs3.x' do: [
		spec package: 'Grease-GemStone300-Core' with: 'Grease-GemStone300-Core-dkh.4'. ].
! !

!ConfigurationOfGrease methodsFor: 'versions' stamp: 'DiegoLont 3/22/2013 11:02'!
version111: spec
	<version: '1.1.1' imports: #('1.1.0-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'release'.
		spec description: ''.
		spec author: 'pmm'.
		spec timestamp: '08/05/2012 19:27'.
		spec 
			package: 'Grease-Core' with: 'Grease-Core-pmm.76';
			package: 'Grease-Tests-Core' with: 'Grease-Tests-Core-pmm.84'. ].

	spec for: #'squeakCommon' do: [
		spec 
			package: 'Grease-Pharo-Core' with: 'Grease-Pharo-Core-pmm.52';
			package: 'Grease-Tests-Pharo-Core' with: 'Grease-Tests-Pharo-Core-pmm.17'. ].

	spec for: #'pharo' do: [
		spec project: 'Refactoring-Core' with: #'stable'.
		spec 
			package: 'Grease-Slime' with: 'Grease-Slime-lr.17';
			package: 'Grease-Tests-Slime' with: 'Grease-Tests-Slime-pmm.11'.
		spec 
			package: 'Grease-Pharo20-Core' with: 'Grease-Pharo20-Core-pmm.10';
			package: 'Grease-Tests-Pharo20-Core' with: 'Grease-Tests-Pharo20-Core-pmm.3'. ].

	spec for: #'pharo1.x' do: [
		spec
			package: 'Grease-Pharo10-Core' with: 'Grease-Pharo10-Core-dkh.4';
			package: 'Grease-Pharo11-Core' with: 'Grease-Pharo11-Core-pmm.1'. ].

	spec for: #'gemstone' do: [
		spec 
			project: 'GsCore' with: '0.245.2';
			project: 'SMTPMail' with: '0.240.1';
			project: 'UTF8' with: '0.240.1';
			project: 'System-Digital-Signatures' with: '0.240.1'.
		spec 
			package: 'Grease-GemStone-Core' with: [
				spec 
					file: 'Grease-GemStone-Core-dkh.47';
					postLoadDoIt: #'initializeTransactionMutex1051'. ];
			package: 'Grease-Tests-GemStone-Core' with: 'Grease-Tests-GemStone-Core-dkh.14'. ].

	spec for: #'gs2.x' do: [
		spec package: 'Grease-GemStone200-Core' with: 'Grease-GemStone200-Core-dkh.2'. ].

	spec for: #'gs2.3.x' do: [
		spec package: 'Grease-GemStone230-Core' with: 'Grease-GemStone230-Core-dkh.4'. ].

	spec for: #'gs2.4.x' do: [
		spec package: 'Grease-GemStone240-Core' with: 'Grease-GemStone240-Core-dkh.3'. ].

	spec for: #'gs3.x' do: [
		spec package: 'Grease-GemStone300-Core' with: 'Grease-GemStone300-Core-dkh.4'. ].
! !
